### Linear regression for fish abundances and species richness in relation to channel age

### Title
# 30 years of large river restoration: how long do restored floodplain channels 
# remain suitable for targeted rheophilic fish in the lower river Rhine? 

### Authors
# T. Stoffers, F.P.L. Collas, G.W. Geerling, A.D. Buijse, L.H. Jans, 
# N. van Kessel, J.A.J. Verreth,  L.A.J. Nagelkerke

### Data analysis

# 1. Housekeeping ----

# Set path for packages
.libPaths('C:/Software/R')

# Set working directory
#setwd("m:\\My Documents\\Projecten\\Twan\\Analyse") #Leo
setwd("C:\\Users\\Stoff004\\OneDrive - WageningenUR\\2020 30 jaar geulen paper\\Analyse\\Analyse R") #Twan

# Empty the environment
remove(list=ls(all=TRUE))  #remove all objects

# load packages
library(plyr)  
library(dplyr)
library(corrplot)
library(vegan)
library(reshape2)
library(ggplot2)
library(MASS)
library(tidyr)
library(scales)
library(psych)
library(cowplot)

# Read raw data file
data <- read.csv(file="Stoffers2020_final_data.csv")
data <- data[,-c(1)] # remove first column

# 2. Fish abundance vs channel age - final analysis [In paper] ---- 

# log transformation of fish abundances

# Species
data$logbarbel      <- log(data$Barbel)  
data$logchub        <- log(data$Chub)
data$logdace        <- log(data$Dace)
data$lognase        <- log(data$Nase)
data$logide         <- log(data$Ide)
data$logwfg         <- log(data$Whitefin_gudgeon)
  
# Ecological groups
data$logallfish     <- log(data$Allfish)  
data$logrheo        <- log(data$Rheo)
data$logeury        <- log(data$Eury)
data$loglimno       <- log(data$Limno)
data$logrheo2       <- log(data$Rheo2)
data$logeury2       <- log(data$Eury2)
data$loglimno2      <- log(data$Limno2)

# Calculate relative abundance of rheophilics
data$percentage_rheo <- (data$Rheo2/data$Allfish)*100 # Calculate percentages of rheophilics per study location

# Geometric mean (log transformation)

# Fish abundances
data2 <- data
data2[,c(34:36)] <- log((data2[,c(34:36)])) # log transformation for calculating geometric mean

exp(mean(data2$Rheo2)) # Calculate geometric mean per trophic guild
exp(sd(data2$Rheo2)) # Calculate sd per trophic guild
exp(mean(data2$Eury2))
exp(sd(data2$Eury2))
exp(mean(data2$Limno2))
exp(sd(data2$Limno2))
#aov(Rheo2, data = data2)

Rheo_ANOVA <- aov(Rheo2 ~ Type, data = data2) # Test for differences in Rheophilics between channel type
Eury_ANOVA <- aov(Eury2 ~ Type, data = data2) # Test for differences in Eurytopics between channel type
Limno_ANOVA <- aov(Limno2 ~ Type, data = data2) # Test for differences in Limnophilics between channel type
summary(Rheo_ANOVA)
summary(Eury_ANOVA)
summary(Limno_ANOVA)
#plot(Rheo_ANOVA) # check for homogeneity
#plot(Eury_ANOVA) # check for homogeneity
#plot(Limno_ANOVA) # check for homogeneity

data2_1SC <- data2[which(data2$Type=="1SC"),] # select 1SC data
data2_2SC <- data2[which(data2$Type=="2SC"),] # select 2SC data

exp(mean(data2_1SC$Rheo2)) # Calculate geom mean per guild per channel type
exp(mean(data2_2SC$Rheo2))
exp(mean(data2_1SC$Eury2))
exp(mean(data2_2SC$Eury2))
exp(mean(data2_1SC$Limno2))
exp(mean(data2_2SC$Limno2))

exp(confint(Rheo_ANOVA)) # Calculate confidence intervals per guild per channel type
exp(confint(Eury_ANOVA))
exp(confint(Limno_ANOVA))

# Species richness ANOVA for channel type
summary(aov(Spec_Rheo2 ~ Type, data = data2)) # Rheophilics
group_by(data2, Type) %>%
  summarise(
    count = n(),
    mean = mean(Spec_Rheo2, na.rm = TRUE),
    sd = sd(Spec_Rheo2, na.rm = TRUE)
  )

summary(aov(Spec_Eury2 ~ Type, data = data2)) # Eurytopics
group_by(data2, Type) %>%
  summarise(
    count = n(),
    mean = mean(Spec_Eury2, na.rm = TRUE),
    sd = sd(Spec_Rheo2, na.rm = TRUE)
  )

#summary(aov(Spec_Limno2 ~ Type, data = data2)) # Limnopilics
#group_by(data2, Type) %>%
#  summarise(
#    count = n(),
#    mean = mean(Spec_Eury2, na.rm = TRUE),
#    sd = sd(Spec_Rheo2, na.rm = TRUE)
#  )


# Chosing regression parameters

# Age of channel
delta_t <- data$Delta_t

# Abundances
rheo    <- data$logrheo2
eury    <- data$logeury2
limno   <- data$loglimno2
#fish   <- data$logallfish

# Species richness
rheo_spec <- data$Spec_Rheo2
eury_spec <- data$Spec_Eury2
limno_spec <- data$Spec_Limno2
#fish_spec <- data$Spec_Allfish

# Linear regression (2nd order polynomial) for abundances

# Rheophilics
fit_rheo <- lm(rheo ~ delta_t + I(delta_t^2))
anova(fit_rheo)
qqnorm(fit_rheo$residuals)
shapiro.test(fit_rheo$residuals)
prd_rheo <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo <- predict(fit_rheo, newdata = prd_rheo, se.fit = TRUE)

prd_rheo$lci <- err_rheo$fit - 1.96 * err_rheo$se.fit
prd_rheo$fit <- err_rheo$fit
prd_rheo$uci <- err_rheo$fit + 1.96 * err_rheo$se.fit
prd_rheo$group <- "Rheophilics"

# Eurytopics
fit_eury <- lm(eury ~ delta_t + I(delta_t^2))
summary(fit_eury)
anova(fit_eury)
qqnorm(fit_eury$residuals)
shapiro.test(fit_eury$residuals)
prd_eury <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury <- predict(fit_eury, newdata = prd_eury, se.fit = TRUE)

#prd_eury$lci <- err_eury$fit - 1.96 * err_eury$se.fit
#prd_eury$fit <- err_eury$fit
#prd_eury$uci <- err_eury$fit + 1.96 * err_eury$se.fit
prd_eury$group <- "Eurytopics"

# Limnophilics
fit_limno <- lm(limno ~ delta_t + I(delta_t^2))
summary(fit_limno)
anova(fit_limno)
qqnorm(fit_limno$residuals)
shapiro.test(fit_limno$residuals)
prd_limno <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno <- predict(fit_limno, newdata = prd_limno, se.fit = TRUE)

#prd_limno$lci <- err_limno$fit - 1.96 * err_limno$se.fit
#prd_limno$fit <- err_limno$fit
#prd_limno$uci <- err_limno$fit + 1.96 * err_limno$se.fit
prd_limno$group <- "Limnophilics"

# Merge the output values
prd_all <- rbind(prd_rheo) # Only pick the significant ecological groups
prd_all <- na.omit(prd_all) # Delete rows with NA

# Dataframe with original data
vals1 <- data[,c("Delta_t","logrheo","logeury","loglimno")]
names(vals1) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
id <- c("delta_t")
vals2 <- na.omit(melt(vals1, id.vars=id))
names(vals2) <- c("delta_t", "group", "fvalue")
vals2$fvalue <- as.numeric(vals2$fvalue)

# Produce plots
# Fix order
prd_all <- transform(prd_all, group=factor(group, levels=unique(group)))
vals2 <- transform(vals2, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c( "darkred","darkgreen","darkblue") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21,21)

# Abundance plots
p_abundance <- ggplot(vals2, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none", 
        axis.title.x=element_blank(), axis.text.x=element_blank(),
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups", values = shapescheme) +
  geom_line(data=prd_all, aes(delta_t, exp(fit), colour=factor(group)), size=1.6) +
  geom_ribbon(data = prd_all, aes(delta_t, ymin = exp(lci), ymax = exp(uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2, aes(x=delta_t, y=exp(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous(limits = c(-7, 1000), trans = log_trans(), breaks = c(0.1, 1, 10, 100, 1000)) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))
labs(x=NULL, y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))  # To suppress X-axis for combination
p_abundance

# Linear regression (2nd order polynomial) for species richness

# Rheophilics
fit_rheo_sp <- lm(rheo_spec ~ delta_t)
summary(fit_rheo_sp)
anova(fit_rheo_sp)
qqnorm(fit_rheo_sp$residuals)
shapiro.test(fit_rheo_sp$residuals)
prd_rheo_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo_sp <- predict(fit_rheo_sp, newdata = prd_rheo_sp, se.fit = TRUE)

prd_rheo_sp$lci <- err_rheo_sp$fit - 1.96 * err_rheo_sp$se.fit
prd_rheo_sp$fit <- err_rheo_sp$fit
prd_rheo_sp$uci <- err_rheo_sp$fit + 1.96 * err_rheo_sp$se.fit
prd_rheo_sp$group <- "Rheophilics"

# Eurytopic fish - species diversity
fit_eury_sp <- lm(eury_spec ~ delta_t + I(delta_t^2))
summary(fit_eury_sp)
anova(fit_eury_sp)
qqnorm(fit_eury_sp$residuals)
shapiro.test(fit_eury_sp$residuals)
prd_eury_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury_sp <- predict(fit_eury_sp, newdata = prd_eury_sp, se.fit = TRUE)

prd_eury_sp$lci <- err_eury_sp$fit - 1.96 * err_eury_sp$se.fit
prd_eury_sp$fit <- err_eury_sp$fit
prd_eury_sp$uci <- err_eury_sp$fit + 1.96 * err_eury_sp$se.fit
prd_eury_sp$group <- "Eurytopics"

# Limnophilic fish - species diversity
fit_limno_sp <- lm(limno_spec ~ delta_t + I(delta_t^2))
summary(fit_limno_sp)
anova(fit_limno_sp)
qqnorm(fit_limno_sp$residuals)
shapiro.test(fit_limno_sp$residuals)
prd_limno_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno_sp <- predict(fit_limno_sp, newdata = prd_limno_sp, se.fit = TRUE)

#prd_limno_sp$lci <- err_limno_sp$fit - 1.96 * err_limno_sp$se.fit
#prd_limno_sp$fit <- err_limno_sp$fit
#prd_limno_sp$uci <- err_limno_sp$fit + 1.96 * err_limno_sp$se.fit
prd_limno_sp$group <- "Limnophilics"

# Merge the output values
prd_all_sp <- rbind(prd_rheo_sp, prd_eury_sp) # Only pick the significant ecological groups
prd_all_sp <- na.omit(prd_all_sp) # Delete rows with NA

# Dataframe with original data
vals1_sp <- data[,c("Delta_t","Spec_Rheo2","Spec_Eury2","Spec_Limno2")]
names(vals1_sp) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
id <- c("delta_t")
vals2_sp <- na.omit(melt(vals1_sp, id.vars=id))
names(vals2_sp) <- c("delta_t","group", "fvalue")
vals2_sp$fvalue <- as.numeric(vals2_sp$fvalue)

# Produce plots
# Fix order
prd_all_sp <- transform(prd_all_sp, group=factor(group, levels=unique(group)))
vals2_sp <- transform(vals2_sp, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c( "darkred","darkgreen","darkblue") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21,21)

p_spec <- ggplot(vals2_sp, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none",
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all_sp, aes(delta_t, (fit), colour=factor(group)), size=1.5) +
  geom_ribbon(data = prd_all_sp, aes(delta_t, ymin = (lci), ymax = (uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2_sp, aes(x=delta_t, y=(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  #scale_y_continuous(labels = scales::number_format(accuracy = 1)) + 
  scale_y_continuous(limits = c(0, 20), breaks=c(0,4,8,12,16,20)) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y="Species richness") +
  theme(strip.text.x = element_blank()) + theme(strip.background = element_blank()) # to suppress strips for combination
p_spec

# Combine graphs
library(cowplot)
cowplot::plot_grid(p_abundance, p_spec, align = "v", ncol = 1, rel_heights = c(0.5, 0.5))

# 2b.Nested model check for referee 2 [Letter to editor] ----

# Final nested model proposed by reviewer (include in paper)
fit_rheo2 <- lm(rheo ~ delta_t + I(delta_t^2) + Type, data=data) # Regression/linear model with 1SC/2SC as fixed factor
summary(fit_rheo2) # No significant effect of channel type

library(INLA)
fit_rheo3a <- inla(rheo ~ delta_t + I(delta_t^2), data=data, control.compute = list(waic=TRUE)) # regression analysis as in paper
fit_rheo3b <- inla(rheo ~ delta_t + I(delta_t^2) + Type, data=data, control.compute = list(waic=TRUE)) # with 1SC/2SC as fixed factor
summary(fit_rheo3a) 
summary(fit_rheo3b) # no effect van Type, WAIC slightly lower (hardly makes a difference with simpler model)

Zlt <- as(model.matrix( ~ 0 + River, data = data), "Matrix") # preparation of data for adding random effects of river branch and locations
Zlts <- as(model.matrix( ~ 0 + River:Name, data = data), "Matrix")


data$riv <- as.factor(apply(Zlt, 1, function(x){names(x)[x == 1]})) 
data$rivname <- as.factor(apply(Zlts, 1, function(x){names(x)[x == 1]}))

# Nested model as proposed by referee 2
inla.nested <- inla(rheo ~ delta_t + I(delta_t^2) + Type +
                      f(riv, model = "iid") +
                      f(rivname, model = "iid"),
                    data = data, 
                    control.compute=list(waic=T),
                    control.predictor = list(compute = TRUE)) # add random effect of individual channels nested in river branch (as proposed by reviewer)
summary(inla.nested) # sigma random effect is really small (1/sqrt(18315)=0.007389185), so no large effect of both random effects!


# 3. 2-sided connected channels [Suppl. materials] ----

# Separate analysis for 2-sided connected channels and 1-sided connected channels
data_2SC <- subset(data, Type == "2SC")
data_1SC <- subset(data, Type == "1SC")

# Age of channel
delta_t <- data_2SC$Delta_t

# Abundances
rheo <- data_2SC$logrheo2
eury <- data_2SC$logeury2
limno <- data_2SC$loglimno2
#fish <- data_2SC$logallfish

# Species richness
rheo_spec <- data_2SC$Spec_Rheo2
eury_spec <- data_2SC$Spec_Eury2
limno_spec <- data_2SC$Spec_Limno2
#fish_spec <- data_2SC$Spec_Allfish

# Percentage rheophilics
#perc_rheo <- data_2SC$percentage_rheo

# Linear regression (2nd order polynomial) for abundances

# Rheophilics
fit_rheo <- lm(rheo ~ delta_t + I(delta_t^2))
summary(fit_rheo)
anova(fit_rheo)
qqnorm(fit_rheo$residuals)
shapiro.test(fit_rheo$residuals)
prd_rheo <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo <- predict(fit_rheo, newdata = prd_rheo, se.fit = TRUE)

prd_rheo$lci <- err_rheo$fit - 1.96 * err_rheo$se.fit
prd_rheo$fit <- err_rheo$fit
prd_rheo$uci <- err_rheo$fit + 1.96 * err_rheo$se.fit
prd_rheo$group <- "Rheophilics"

# Eurytopics
fit_eury <- lm(eury ~ delta_t + I(delta_t^2))
summary(fit_eury)
anova(fit_eury)
qqnorm(fit_eury$residuals)
shapiro.test(fit_eury$residuals)
prd_eury <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury <- predict(fit_eury, newdata = prd_eury, se.fit = TRUE)

#prd_eury$lci <- err_eury$fit - 1.96 * err_eury$se.fit
#prd_eury$fit <- err_eury$fit
#prd_eury$uci <- err_eury$fit + 1.96 * err_eury$se.fit
prd_eury$group <- "Eurytopics"

# Limnophilics
fit_limno <- lm(limno ~ delta_t + I(delta_t^2))
summary(fit_limno)
anova(fit_limno)
qqnorm(fit_limno$residuals)
shapiro.test(fit_limno$residuals)
prd_limno <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno <- predict(fit_limno, newdata = prd_limno, se.fit = TRUE)

prd_limno$lci <- err_limno$fit - 1.96 * err_limno$se.fit
prd_limno$fit <- err_limno$fit
prd_limno$uci <- err_limno$fit + 1.96 * err_limno$se.fit
prd_limno$group <- "Limnophilics"

# Merge the output values
prd_all <- rbind(prd_rheo, prd_limno)
prd_all <- na.omit(prd_all) # Delete rows with NA

# Dataframe with original data
vals1 <- data_2SC[,c("Delta_t","logrheo","logeury","loglimno")]
names(vals1) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
vals2 <- na.omit(melt(vals1, id.vars="delta_t"))
names(vals2) <- c("delta_t", "group", "fvalue")
vals2$fvalue <- as.numeric(vals2$fvalue)

# Produce plots
# Fix order
prd_all <- transform(prd_all, group=factor(group, levels=unique(group)))
vals2 <- transform(vals2, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("darkred","darkgreen", "darkblue")
shapescheme <- c(21,21,21)

# Abundance plots
p_abundance <- ggplot(vals2, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none", 
        axis.title.x=element_blank(), axis.text.x=element_blank(),
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all, aes(delta_t, exp(fit), colour=factor(group)), size=1.5) +
  geom_ribbon(data = prd_all, aes(delta_t, ymin = exp(lci), ymax = exp(uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2, aes(x=delta_t, y=exp(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous(trans = log_trans(), breaks = c(0.1, 1 , 10 , 100 , 1000 )) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))
labs(x=NULL, y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))  # To suppress X-axis for combination
p_abundance

# Linear regression (2nd order polynomial) for species richness

# Rheophilics
fit_rheo_sp <- lm(rheo_spec ~ delta_t + I(delta_t^2), data = data_2SC)
summary(fit_rheo_sp)
anova(fit_rheo_sp)
qqnorm(fit_rheo_sp$residuals)
shapiro.test(fit_rheo_sp$residuals)
prd_rheo_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo_sp <- predict(fit_rheo_sp, newdata = prd_rheo_sp, se.fit = TRUE)

#prd_rheo_sp$lci <- err_rheo_sp$fit - 1.96 * err_rheo_sp$se.fit
#prd_rheo_sp$fit <- err_rheo_sp$fit
#prd_rheo_sp$uci <- err_rheo_sp$fit + 1.96 * err_rheo_sp$se.fit
prd_rheo_sp$group <- "Rheophilics"

# Eurytopic fish - species diversity
fit_eury_sp <- lm(eury_spec ~ delta_t + I(delta_t^2), data = data_2SC)
summary(fit_eury_sp)
anova(fit_eury_sp)
qqnorm(fit_eury_sp$residuals)
shapiro.test(fit_eury_sp$residuals)
prd_eury_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury_sp <- predict(fit_eury_sp, newdata = prd_eury_sp, se.fit = TRUE)

#prd_eury_sp$lci <- err_eury_sp$fit - 1.96 * err_eury_sp$se.fit
#prd_eury_sp$fit <- err_eury_sp$fit
#prd_eury_sp$uci <- err_eury_sp$fit + 1.96 * err_eury_sp$se.fit
prd_eury_sp$group <- "Eurytopics"

# Limnophilic fish - species diversity
fit_limno_sp <- lm(limno_spec ~ delta_t + I(delta_t^2), data = data_2SC)
summary(fit_limno_sp)
anova(fit_limno_sp)
qqnorm(fit_limno_sp$residuals)
shapiro.test(fit_limno_sp$residuals)
prd_limno_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno_sp <- predict(fit_limno_sp, newdata = prd_limno_sp, se.fit = TRUE)

prd_limno_sp$lci <- err_limno_sp$fit - 1.96 * err_limno_sp$se.fit
prd_limno_sp$fit <- err_limno_sp$fit
prd_limno_sp$uci <- err_limno_sp$fit + 1.96 * err_limno_sp$se.fit
prd_limno_sp$group <- "Limnophilics"

# Merge the output values
prd_all_sp <- rbind(prd_limno_sp)
prd_all_sp <- na.omit(prd_all_sp) # Delete rows with NA

# Dataframe with original data
vals1_sp <- data_2SC[,c("Delta_t","Spec_Rheo","Spec_Eury","Spec_Limno")]
names(vals1_sp) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
vals2_sp <- na.omit(melt(vals1_sp, id.vars="delta_t"))
names(vals2_sp) <- c("delta_t", "group", "fvalue")
vals2_sp$fvalue <- as.numeric(vals2_sp$fvalue)

# Produce plots
# Fix order
prd_all_sp <- transform(prd_all_sp, group=factor(group, levels=unique(group)))
vals2_sp <- transform(vals2_sp, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("darkred","darkgreen","darkblue")
shapescheme <- c(21,21,21)

p_spec <- ggplot(vals2_sp, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none",
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all_sp, aes(delta_t, (fit), colour=factor(group)), size=1.5) +
  geom_ribbon(data = prd_all_sp, aes(delta_t, ymin = (lci), ymax = (uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2_sp, aes(x=delta_t, y=(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  #scale_y_continuous(labels = scales::number_format(accuracy = 1)) + 
  scale_y_continuous(breaks=c(0,4,8,12,16)) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y="Species richness") +
  theme(strip.text.x = element_blank()) + theme(strip.background = element_blank()) # to suppress strips for combination
p_spec

# Combine graphs
library(cowplot)
cowplot::plot_grid(p_abundance, p_spec, align = "v", ncol = 1, rel_heights = c(0.46, 0.54))


# 4. 1-sided connected channels [Suppl. materials] ----

# Separate analysis for 2-sided connected channels
data_1SC <- subset(data, Type == "1SC")

# Age of channel
delta_t <- data_1SC$Delta_t

# Abundances
rheo <- data_1SC$logrheo2
eury <- data_1SC$logeury2
limno <- data_1SC$loglimno2
#fish <- data_1SC$logallfish

# Species richness
rheo_spec <- data_1SC$Spec_Rheo2
eury_spec <- data_1SC$Spec_Eury2
limno_spec <- data_1SC$Spec_Limno2
#fish_spec <- data_1SC$Spec_Allfish

# Percentage rheophilics
#perc_rheo <- data_1SC$percentage_rheo


# Linear regression (2nd order polynomial) for abundances

# Rheophilics
fit_rheo <- lm(rheo ~ delta_t + I(delta_t^2))
summary(fit_rheo)
anova(fit_rheo)
qqnorm(fit_rheo$residuals)
shapiro.test(fit_rheo$residuals)
prd_rheo <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo <- predict(fit_rheo, newdata = prd_rheo, se.fit = TRUE)

prd_rheo$lci <- err_rheo$fit - 1.96 * err_rheo$se.fit
prd_rheo$fit <- err_rheo$fit
prd_rheo$uci <- err_rheo$fit + 1.96 * err_rheo$se.fit
prd_rheo$group <- "Rheophilics"

# Eurytopics
fit_eury <- lm(eury ~ delta_t + I(delta_t^2))
summary(fit_eury)
anova(fit_eury)
qqnorm(fit_eury$residuals)
shapiro.test(fit_eury$residuals)
prd_eury <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury <- predict(fit_eury, newdata = prd_eury, se.fit = TRUE)

#prd_eury$lci <- err_eury$fit - 1.96 * err_eury$se.fit
#prd_eury$fit <- err_eury$fit
#prd_eury$uci <- err_eury$fit + 1.96 * err_eury$se.fit
prd_eury$group <- "Eurytopics"

# Limnophilics
fit_limno <- lm(limno ~ delta_t + I(delta_t^2))
summary(fit_limno)
anova(fit_limno)
qqnorm(fit_limno$residuals)
shapiro.test(fit_limno$residuals)
prd_limno <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno <- predict(fit_limno, newdata = prd_limno, se.fit = TRUE)

#prd_limno$lci <- err_limno$fit - 1.96 * err_limno$se.fit
#prd_limno$fit <- err_limno$fit
#prd_limno$uci <- err_limno$fit + 1.96 * err_limno$se.fit
prd_limno$group <- "Limnophilics"

# Merge the output values
prd_all <- rbind(prd_rheo)
prd_all <- na.omit(prd_all) # Delete rows with NA

# Dataframe with original data
vals1 <- data_1SC[,c("Delta_t","logrheo","logeury","loglimno")]
names(vals1) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
vals2 <- na.omit(melt(vals1, id.vars="delta_t"))
names(vals2) <- c("delta_t", "group", "fvalue")
vals2$fvalue <- as.numeric(vals2$fvalue)

# Produce plots
# Fix order
prd_all <- transform(prd_all, group=factor(group, levels=unique(group)))
vals2 <- transform(vals2, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("darkred","darkgreen","darkblue")
shapescheme <- c(21,21,21)

# Abundance plots
p_abundance <- ggplot(vals2, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none", 
        axis.title.x=element_blank(), axis.text.x=element_blank(),
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all, aes(delta_t, exp(fit), colour=factor(group)), size=1.5) +
  geom_ribbon(data = prd_all, aes(delta_t, ymin = exp(lci), ymax = exp(uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2, aes(x=delta_t, y=exp(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous(trans = log_trans(), breaks = c(0.1, 1 , 10 , 100 , 1000 )) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))
labs(x=NULL, y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))  # To suppress X-axis for combination
p_abundance

# Linear regression (2nd order polynomial) for species richness

# Rheophilics
fit_rheo_sp <- lm(rheo_spec ~ delta_t + I(delta_t^2), data = data_1SC)
summary(fit_rheo_sp)
anova(fit_rheo_sp)
qqnorm(fit_rheo_sp$residuals)
shapiro.test(fit_rheo_sp$residuals)
prd_rheo_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo_sp <- predict(fit_rheo_sp, newdata = prd_rheo_sp, se.fit = TRUE)

#prd_rheo_sp$lci <- err_rheo_sp$fit - 1.96 * err_rheo_sp$se.fit
#prd_rheo_sp$fit <- err_rheo_sp$fit
#prd_rheo_sp$uci <- err_rheo_sp$fit + 1.96 * err_rheo_sp$se.fit
prd_rheo_sp$group <- "Rheophilics"

# Eurytopic fish - species diversity
fit_eury_sp <- lm(eury_spec ~ delta_t + I(delta_t^2), data = data_1SC)
summary(fit_eury_sp)
anova(fit_eury_sp)
qqnorm(fit_eury_sp$residuals)
shapiro.test(fit_eury_sp$residuals)
prd_eury_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury_sp <- predict(fit_eury_sp, newdata = prd_eury_sp, se.fit = TRUE)

#prd_eury_sp$lci <- err_eury_sp$fit - 1.96 * err_eury_sp$se.fit
#prd_eury_sp$fit <- err_eury_sp$fit
#prd_eury_sp$uci <- err_eury_sp$fit + 1.96 * err_eury_sp$se.fit
prd_eury_sp$group <- "Eurytopics"

# Limnophilic fish - species diversity
fit_limno_sp <- lm(limno_spec ~ delta_t + I(delta_t^2), data = data_1SC)
summary(fit_limno_sp)
anova(fit_limno_sp)
qqnorm(fit_limno_sp$residuals)
shapiro.test(fit_limno_sp$residuals)
prd_limno_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno_sp <- predict(fit_limno_sp, newdata = prd_limno_sp, se.fit = TRUE)

#prd_limno_sp$lci <- err_limno_sp$fit - 1.96 * err_limno_sp$se.fit
#prd_limno_sp$fit <- err_limno_sp$fit
#prd_limno_sp$uci <- err_limno_sp$fit + 1.96 * err_limno_sp$se.fit
prd_limno_sp$group <- "Limnophilics"


# Dataframe with original data
vals1_sp <- data_1SC[,c("Delta_t","Spec_Rheo","Spec_Eury","Spec_Limno")]
names(vals1_sp) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
vals2_sp <- na.omit(melt(vals1_sp, id.vars="delta_t"))
names(vals2_sp) <- c("delta_t", "group", "fvalue")
vals2_sp$fvalue <- as.numeric(vals2_sp$fvalue)

# Produce plots
# Fix order
vals2_sp <- transform(vals2_sp, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("darkblue","darkred","darkgreen")
shapescheme <- c(21,21,21)

p_spec <- ggplot(vals2_sp, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none",
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_point(data=vals2_sp, aes(x=delta_t, y=(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  #scale_y_continuous(labels = scales::number_format(accuracy = 1)) + 
  scale_y_continuous(breaks=c(0,4,8,12,16)) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y="Species richness") +
  theme(strip.text.x = element_blank()) + theme(strip.background = element_blank()) # to suppress strips for combination
p_spec

# Combine graphs
library(cowplot)
cowplot::plot_grid(p_abundance, p_spec, align = "v", ncol = 1, rel_heights = c(0.46, 0.54))


# 5. Analysis excluding invasive gobies [Suppl. materials] ----

# Age of channel
delta_t <- data$Delta_t

# Abundances
rheo2 <- data$logrheo
eury2 <- data$logeury
limno2 <- data$loglimno
#fish <- data$logallfish

# Species richness
rheo_spec2 <- data$Spec_Rheo
eury_spec2 <- data$Spec_Eury
limno_spec2 <- data$Spec_Limno
#fish_spec <- data$Spec_Allfish

# Linear regression (2nd order polynomial) for abundances (including invasive gobies)

# Rheophilics
fit_rheo <- lm(rheo2 ~ delta_t + I(delta_t^2))
summary(fit_rheo)
anova(fit_rheo)
qqnorm(fit_rheo$residuals)
shapiro.test(fit_rheo$residuals)
prd_rheo <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo <- predict(fit_rheo, newdata = prd_rheo, se.fit = TRUE)

prd_rheo$lci <- err_rheo$fit - 1.96 * err_rheo$se.fit
prd_rheo$fit <- err_rheo$fit
prd_rheo$uci <- err_rheo$fit + 1.96 * err_rheo$se.fit
prd_rheo$group <- "Rheophilics"

# Eurytopics
fit_eury <- lm(eury2 ~ delta_t + I(delta_t^2))
summary(fit_eury)
anova(fit_eury)
qqnorm(fit_eury$residuals)
shapiro.test(fit_eury$residuals)
prd_eury <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury <- predict(fit_eury, newdata = prd_eury, se.fit = TRUE)

#prd_eury$lci <- err_eury$fit - 1.96 * err_eury$se.fit
#prd_eury$fit <- err_eury$fit
#prd_eury$uci <- err_eury$fit + 1.96 * err_eury$se.fit
prd_eury$group <- "Eurytopics"

# Limnophilics
fit_limno <- lm(limno2 ~ delta_t + I(delta_t^2))
summary(fit_limno)
anova(fit_limno)
qqnorm(fit_limno$residuals)
shapiro.test(fit_limno$residuals)
prd_limno <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno <- predict(fit_limno, newdata = prd_limno, se.fit = TRUE)

#prd_limno$lci <- err_limno$fit - 1.96 * err_limno$se.fit
#prd_limno$fit <- err_limno$fit
#prd_limno$uci <- err_limno$fit + 1.96 * err_limno$se.fit
prd_limno$group <- "Limnophilics"

# Merge the output values
prd_all <- rbind(prd_rheo)
prd_all <- na.omit(prd_all) # Delete rows with NA

# Dataframe with original data
vals1 <- data[,c("Delta_t","logrheo","logeury","loglimno")]
names(vals1) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
id <- c("delta_t")
vals2 <- na.omit(melt(vals1, id.vars=id))
names(vals2) <- c("delta_t", "group", "fvalue")
vals2$fvalue <- as.numeric(vals2$fvalue)

# Produce plots
# Fix order
prd_all <- transform(prd_all, group=factor(group, levels=unique(group)))
vals2 <- transform(vals2, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("darkred","darkgreen","darkblue") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21,21)

# Abundance plots
p_abundance <- ggplot(vals2, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none", 
        axis.title.x=element_blank(), axis.text.x=element_blank(),
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all, aes(delta_t, exp(fit), colour=factor(group)), size=1.5) +
  geom_ribbon(data = prd_all, aes(delta_t, ymin = exp(lci), ymax = exp(uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2, aes(x=delta_t, y=exp(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous(trans = log_trans(), breaks = c(0.1, 1 , 10 , 100 , 1000 )) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))
labs(x=NULL, y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))  # To suppress X-axis for combination
p_abundance

# Linear regression (2nd order polynomial) for species richness

# Rheophilics
fit_rheo_sp <- lm(rheo_spec2 ~ delta_t + I(delta_t^2), data = data)
summary(fit_rheo_sp)
anova(fit_rheo_sp)
qqnorm(fit_rheo_sp$residuals)
shapiro.test(fit_rheo_sp$residuals)
prd_rheo_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo_sp <- predict(fit_rheo_sp, newdata = prd_rheo_sp, se.fit = TRUE)

prd_rheo_sp$lci <- err_rheo_sp$fit - 1.96 * err_rheo_sp$se.fit
prd_rheo_sp$fit <- err_rheo_sp$fit
prd_rheo_sp$uci <- err_rheo_sp$fit + 1.96 * err_rheo_sp$se.fit
prd_rheo_sp$group <- "Rheophilics"

# Eurytopic fish - species diversity
fit_eury_sp <- lm(eury_spec2 ~ delta_t + I(delta_t^2), data = data)
summary(fit_eury_sp)
anova(fit_eury_sp)
qqnorm(fit_eury_sp$residuals)
shapiro.test(fit_eury_sp$residuals)
prd_eury_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury_sp <- predict(fit_eury_sp, newdata = prd_eury_sp, se.fit = TRUE)

prd_eury_sp$lci <- err_eury_sp$fit - 1.96 * err_eury_sp$se.fit
prd_eury_sp$fit <- err_eury_sp$fit
prd_eury_sp$uci <- err_eury_sp$fit + 1.96 * err_eury_sp$se.fit
prd_eury_sp$group <- "Eurytopics"

# Limnophilic fish - species diversity
fit_limno_sp <- lm(limno_spec2 ~ delta_t + I(delta_t^2), data = data)
summary(fit_limno_sp)
anova(fit_limno_sp)
qqnorm(fit_limno_sp$residuals)
shapiro.test(fit_limno_sp$residuals)
prd_limno_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno_sp <- predict(fit_limno_sp, newdata = prd_limno_sp, se.fit = TRUE)

#prd_limno_sp$lci <- err_limno_sp$fit - 1.96 * err_limno_sp$se.fit
#prd_limno_sp$fit <- err_limno_sp$fit
#prd_limno_sp$uci <- err_limno_sp$fit + 1.96 * err_limno_sp$se.fit
prd_limno_sp$group <- "Limnophilics"

# Merge the output values
prd_all_sp <- rbind(prd_rheo_sp, prd_eury_sp)
prd_all_sp <- na.omit(prd_all_sp) # Delete rows with NA

# Dataframe with original data
vals1_sp <- data[,c("Delta_t","Spec_Rheo","Spec_Eury","Spec_Limno")]
names(vals1_sp) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
id <- c("delta_t")
vals2_sp <- na.omit(melt(vals1_sp, id.vars=id))
names(vals2_sp) <- c("delta_t","group", "fvalue")
vals2_sp$fvalue <- as.numeric(vals2_sp$fvalue)

# Produce plots
# Fix order
prd_all_sp <- transform(prd_all_sp, group=factor(group, levels=unique(group)))
vals2_sp <- transform(vals2_sp, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("darkred","darkgreen","darkblue") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21,21)

p_spec <- ggplot(vals2_sp, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none",
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all_sp, aes(delta_t, (fit), colour=factor(group)), size=1.5) +
  geom_ribbon(data = prd_all_sp, aes(delta_t, ymin = (lci), ymax = (uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2_sp, aes(x=delta_t, y=(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  #scale_y_continuous(labels = scales::number_format(accuracy = 1)) + 
  scale_y_continuous(breaks=c(0,4,8,12,16)) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y="Species richness") +
  theme(strip.text.x = element_blank()) + theme(strip.background = element_blank()) # to suppress strips for combination
p_spec

# Combine graphs
library(cowplot)
cowplot::plot_grid(p_abundance, p_spec, align = "v", ncol = 1, rel_heights = c(0.46, 0.54))


# 6. Rheophilics vs 'rheophilics excluding ide' [In paper] ----

# Age of channel
delta_t <- data$Delta_t

# Abundances
rheo <- data$logrheo2
data$rheo_light <- data$Rheo2-data$Ide # Calculate rheophilic fish abundances without including "ide" 
min_abund <- min(data$rheo_light[which(data$rheo_light!=0)])
data$rheo_light <- log(data$rheo_light + 0.5 * min_abund) # Calculate rheophilic fish abundances without including "ide" 
                                                           # log(difference + half of the lowest non-zero value)
rheo_light <- data$rheo_light

# Linear regression (2nd order polynomial) for abundances (including invasive gobies)

# Rheophilics
fit_rheo <- lm(rheo ~ delta_t + I(delta_t^2))
summary(fit_rheo)
anova(fit_rheo)
qqnorm(fit_rheo$residuals)
shapiro.test(fit_rheo$residuals)
prd_rheo <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo <- predict(fit_rheo, newdata = prd_rheo, se.fit = TRUE)

prd_rheo$lci <- err_rheo$fit - 1.96 * err_rheo$se.fit
prd_rheo$fit <- err_rheo$fit
prd_rheo$uci <- err_rheo$fit + 1.96 * err_rheo$se.fit
prd_rheo$group <- "Rheophilics"

# Rheophilics without "ide"
fit_rheo_light <- lm(rheo_light ~ delta_t + I(delta_t^2))
summary(fit_rheo_light)
anova(fit_rheo_light)
qqnorm(fit_rheo_light$residuals)
shapiro.test(fit_rheo_light$residuals)
prd_rheo_light <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo_light <- predict(fit_rheo_light, newdata = prd_rheo_light, se.fit = TRUE)

prd_rheo_light$lci <- err_rheo_light$fit - 1.96 * err_rheo_light$se.fit
prd_rheo_light$fit <- err_rheo_light$fit
prd_rheo_light$uci <- err_rheo_light$fit + 1.96 * err_rheo_light$se.fit
prd_rheo_light$group <- "Rheophilics without Ide"

# Dataframe with original data
vals1 <- data[,c("Delta_t","logrheo","rheo_light")]
names(vals1) <- c("delta_t", "Rheophilics", "Rheophilics without Ide")
id <- c("delta_t")
vals2 <- na.omit(melt(vals1, id.vars=id))
names(vals2) <- c("delta_t", "group", "fvalue")
vals2$fvalue <- as.numeric(vals2$fvalue)

# Produce plots
prd_all <- rbind(prd_rheo, prd_rheo_light)
prd_all <- na.omit(prd_all) # Delete rows with NA

# Fix order
prd_all <- transform(prd_all, group=factor(group, levels=unique(group)))
vals2 <- transform(vals2, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("darkblue", "darkblue") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21,21)

# Abundance plots
p_abundance <- ggplot(vals2, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(1.5), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(1.5)), 
        strip.text=element_text(size=rel(1.5)), legend.position="none", 
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all, aes(delta_t, exp(fit), colour=factor(group)), size=1.5) +
  geom_ribbon(data = prd_all, aes(delta_t, ymin = exp(lci), ymax = exp(uci), fill=factor(group)), alpha=.3, colour=NA) + 
  #geom_point(data=vals2, aes(x=delta_t, y=exp(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous(trans = log_trans(), breaks = c(0.1, 1 , 10 , 100 , 1000 )) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))
p_abundance


# 7. Individual rheophilic species abundances [Suppl. materials] --------

# Age of channel
delta_t <- data$Delta_t

# Abundances of most abundant rheophilic species
ide              <- data$logide
whitefin_gudgeon <- data$logwfg
nase             <- data$lognase
dace             <- data$logdace
barbel           <- data$logbarbel
chub             <- data$logchub

# Linear regression (2nd order polynomial) for abundances (including invasive gobies)

# Ide
fit_ide <- lm(ide ~ delta_t + I(delta_t^2))
summary(fit_ide)
anova(fit_ide)
qqnorm(fit_ide$residuals)
shapiro.test(fit_ide$residuals)
prd_ide <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_ide <- predict(fit_ide, newdata = prd_ide, se.fit = TRUE)

prd_ide$lci <- err_ide$fit - 1.96 * err_ide$se.fit
prd_ide$fit <- err_ide$fit
prd_ide$uci <- err_ide$fit + 1.96 * err_ide$se.fit
prd_ide$group <- "Ide"

# Whitefin gudgeon
fit_gudgeon <- lm(whitefin_gudgeon ~ delta_t)
summary(fit_gudgeon)
anova(fit_gudgeon)
qqnorm(fit_gudgeon$residuals)
shapiro.test(fit_gudgeon$residuals)
prd_gudgeon <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_gudgeon <- predict(fit_gudgeon, newdata = prd_gudgeon, se.fit = TRUE)

#prd_gudgeon$lci <- err_gudgeon$fit - 1.96 * err_gudgeon$se.fit
#prd_gudgeon$fit <- err_gudgeon$fit
#prd_gudgeon$uci <- err_gudgeon$fit + 1.96 * err_gudgeon$se.fit
prd_gudgeon$group <- "Whitefin gudgeon"

# Nase
fit_nase <- lm(nase ~ delta_t + I(delta_t^2))
summary(fit_nase)
anova(fit_nase)
qqnorm(fit_nase$residuals)
shapiro.test(fit_nase$residuals)
prd_nase <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_nase <- predict(fit_nase, newdata = prd_nase, se.fit = TRUE)

#prd_nase$lci <- err_nase$fit - 1.96 * err_nase$se.fit
#prd_nase$fit <- err_nase$fit
#prd_nase$uci <- err_nase$fit + 1.96 * err_nase$se.fit
prd_nase$group <- "Nase"

# Dace
fit_dace <- lm(dace ~ delta_t + I(delta_t^2)) # linear regression has slightly better fit
summary(fit_dace)
anova(fit_dace)
qqnorm(fit_dace$residuals)
shapiro.test(fit_dace$residuals)
prd_dace <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_dace <- predict(fit_dace, newdata = prd_dace, se.fit = TRUE)

#prd_dace$lci <- err_dace$fit - 1.96 * err_dace$se.fit
#prd_dace$fit <- err_dace$fit
#prd_dace$uci <- err_dace$fit + 1.96 * err_dace$se.fit
prd_dace$group <- "Dace"

# Barbel
fit_barbel <- lm(barbel ~ delta_t) # linear regression has slightly better fit
summary(fit_barbel)
anova(fit_barbel)
qqnorm(fit_barbel$residuals)
shapiro.test(fit_barbel$residuals)
prd_barbel <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_barbel <- predict(fit_barbel, newdata = prd_barbel, se.fit = TRUE)

#prd_barbel$lci <- err_barbel$fit - 1.96 * err_barbel$se.fit
#prd_barbel$fit <- err_barbel$fit
#prd_barbel$uci <- err_barbel$fit + 1.96 * err_barbel$se.fit
prd_barbel$group <- "Barbel"

# Chub
fit_chub <- lm(chub ~ delta_t) # linear regression has slightly better fit
summary(fit_chub)
anova(fit_chub)
qqnorm(fit_chub$residuals)
shapiro.test(fit_chub$residuals)
prd_chub <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_chub <- predict(fit_chub, newdata = prd_chub, se.fit = TRUE)

#prd_chub$lci <- err_chub$fit - 1.96 * err_chub$se.fit
#prd_chub$fit <- err_chub$fit
#prd_chub$uci <- err_chub$fit + 1.96 * err_chub$se.fit
prd_chub$group <- "Chub"

# Merge the output values 1
prd_all <- rbind(prd_ide)
prd_all <- na.omit(prd_all) # Delete rows with NA

# Dataframe with original data 1
vals1 <- data[,c("Delta_t", "logide", "logwfg", "lognase")]
names(vals1) <- c("delta_t", "Ide", "Whitefin gudgeon", "Nase")
id <- c("delta_t")
vals2 <- na.omit(melt(vals1, id.vars=id))
names(vals2) <- c("delta_t", "group", "fvalue")
vals2$fvalue <- as.numeric(vals2$fvalue)

# Produce plots  1
# Fix order
prd_all <- transform(prd_all, group=factor(group, levels=unique(group)))
vals2 <- transform(vals2, group=factor(group, levels=unique(group)))

# Dataframe with original data 2
vals1a <- data[,c("Delta_t", "logdace", "logbarbel", "logchub")]
names(vals1a) <- c("delta_t", "Dace", "Barbel", "Chub")
id <- c("delta_t")
vals2a <- na.omit(melt(vals1a, id.vars=id))
names(vals2a) <- c("delta_t", "group", "fvalue")
vals2a$fvalue <- as.numeric(vals2a$fvalue)

# Produce plots 2
# Fix order
vals2a <- transform(vals2a, group=factor(group, levels=unique(group)))

# Colour and shape schemes for both plots 
colscheme <- c("darkblue","darkblue","darkblue") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21,21)


# Abundance plots

# First ide, nase, dace
p_abundance <- ggplot(vals2, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none", 
        axis.title.x=element_blank(), axis.text.x=element_blank(),
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all, aes(delta_t, exp(fit), colour=factor(group)), size=1.5) +
  geom_ribbon(data = prd_all, aes(delta_t, ymin = exp(lci), ymax = exp(uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2, aes(x=delta_t, y=exp(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous(trans = log_trans(), breaks = c(0.1, 1 , 10 , 100 , 1000 )) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))
labs(x=NULL, y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))  # To suppress X-axis for combination
p_abundance

# Then barbel, chub, gudgeon
p_abundance2 <- ggplot(vals2a, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none",
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_point(data=vals2a, aes(x=delta_t, y=exp(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous(trans = log_trans(), breaks = c(0.1,1)) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))
p_abundance2

# And now combine the 2 plots
library(cowplot)
cowplot::plot_grid(p_abundance, p_abundance2, align = "v", ncol = 1, rel_heights = c(0.46, 0.54))


# 8. Percentage reophilics [In paper] ----

# Age of channel
delta_t <- data$Delta_t
perc_rheo <- data$percentage_rheo

fit_perc_rheo <- lm(perc_rheo ~ delta_t + I(delta_t^2))
summary(fit_perc_rheo)
anova(fit_perc_rheo)
qqnorm(fit_perc_rheo$residuals)
shapiro.test(fit_perc_rheo$residuals)
prd_perc_rheo <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_perc_rheo <- predict(fit_perc_rheo, newdata = prd_perc_rheo, se.fit = TRUE)

prd_perc_rheo$lci <- err_perc_rheo$fit - 1.96 * err_perc_rheo$se.fit
prd_perc_rheo$fit <- err_perc_rheo$fit
prd_perc_rheo$uci <- err_perc_rheo$fit + 1.96 * err_perc_rheo$se.fit
prd_perc_rheo$group <- "Rheophilics"


# Create figure percentages rheophilics
element_textbox <- function(...) {
  el <- element_text(...)
  class(el) <- c("element_textbox", class(el))
  el
}

element_grob.element_textbox <- function(element, ...) {
  text_grob <- NextMethod()
  rect_grob <- element_grob(calc_element("strip.background", theme_bw()))
  
  ggplot2:::absoluteGrob(
    grid::gList(
      element_grob(calc_element("strip.background", theme_bw())),
      text_grob
    ),
    height = grid::grobHeight(text_grob), 
    width = grid::unit(1, "npc")
  )
}

# Colour and shape schemes
colscheme <- c("darkblue") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21)

Percentage_rheophilics <- ggplot(data) +
  theme_bw() +
  theme(plot.title = element_textbox(hjust = 0.5, size=28, margin = margin(t = 5, b = 5)), 
        axis.text=element_text(size=rel(2.5), colour = "black"), 
        axis.title=element_text(size=rel(2.5), colour ="black"),
        strip.text=element_text(size=rel(2.5)), legend.position="none",
        axis.ticks = element_line(colour = "black", size = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        plot.margin=unit(c(0.5,0.7,0.2,0.2),"cm")) + 
  scale_colour_manual(name = "groups", values = colscheme)  +
  scale_shape_manual(name = "groups", values = shapescheme, aesthetics=c("colour","fill")) +
  geom_line(data=prd_perc_rheo, aes(delta_t, fit), colour="darkblue", size=2) +
  geom_ribbon(data = prd_perc_rheo, aes(delta_t, ymin = lci, ymax = uci), alpha=.3, fill="darkblue") +
  geom_point(data=data, aes(x=delta_t, y=percentage_rheo), alpha=0.6, colour="darkblue", size=7) +
  labs(x =expression(paste("Age"," ",(Delta*t))), y = "Relative abundance (%)", title = "Rheophilics") +
  scale_x_continuous(limits = c(2, 30), breaks=c(0,10,20,30)) +
  scale_y_continuous(limits = c(-50, 100), breaks=c(0,25,50,75,100))
Percentage_rheophilics




# 9. Analysis of different parts of the data set [Suppl. materials] ----


### Load original dataset - complete data set
data_complete <- read.csv(file="master_datafile.csv")

# Chosing regression parameters

# Age of channel
delta_t <- data_complete$Delta_t

# Abundances
data_complete$logrheo2    <- log(data_complete$Rheo2)
data_complete$logeury2    <- log(data_complete$Eury2)
data_complete$loglimno2   <- log(data_complete$Limno2)
data_complete$logallfish2   <- log(data_complete$Allfish)

rheo    <- data_complete$logrheo2
eury    <- data_complete$logeury2
limno   <- data_complete$loglimno2
#fish   <- data_complete$logallfish2

# Species richness
rheo_spec <- data_complete$Spec_Rheo2
eury_spec <- data_complete$Spec_Eury2
limno_spec <- data_complete$Spec_Limno2
#fish_spec <- data_complete$Spec_Allfish

# Linear regression (2nd order polynomial) for abundances

# Rheophilics
fit_rheo <- lm(rheo ~ delta_t + I(delta_t^2))
summary(fit_rheo)
anova(fit_rheo)
qqnorm(fit_rheo$residuals)
shapiro.test(fit_rheo$residuals)
prd_rheo <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo <- predict(fit_rheo, newdata = prd_rheo, se.fit = TRUE)

prd_rheo$lci <- err_rheo$fit - 1.96 * err_rheo$se.fit
prd_rheo$fit <- err_rheo$fit
prd_rheo$uci <- err_rheo$fit + 1.96 * err_rheo$se.fit
prd_rheo$group <- "Rheophilics"

# Eurytopics
fit_eury <- lm(eury ~ delta_t + I(delta_t^2))
summary(fit_eury)
anova(fit_eury)
qqnorm(fit_eury$residuals)
shapiro.test(fit_eury$residuals)
prd_eury <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury <- predict(fit_eury, newdata = prd_eury, se.fit = TRUE)

#prd_eury$lci <- err_eury$fit - 1.96 * err_eury$se.fit
#prd_eury$fit <- err_eury$fit
#prd_eury$uci <- err_eury$fit + 1.96 * err_eury$se.fit
prd_eury$group <- "Eurytopics"

# Limnophilics
fit_limno <- lm(limno ~ delta_t + I(delta_t^2))
summary(fit_limno)
anova(fit_limno)
qqnorm(fit_limno$residuals)
shapiro.test(fit_limno$residuals)
prd_limno <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno <- predict(fit_limno, newdata = prd_limno, se.fit = TRUE)

#prd_limno$lci <- err_limno$fit - 1.96 * err_limno$se.fit
#prd_limno$fit <- err_limno$fit
#prd_limno$uci <- err_limno$fit + 1.96 * err_limno$se.fit
prd_limno$group <- "Limnophilics"

# Merge the output values
prd_all <- rbind(prd_rheo) # Only pick the significant ecological groups
prd_all <- na.omit(prd_all) # Delete rows with NA

# Dataframe with original data
vals1 <- data_complete[,c("Delta_t","logrheo2","logeury2","loglimno2")]
names(vals1) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
id <- c("delta_t")
vals2 <- na.omit(melt(vals1, id.vars=id))
names(vals2) <- c("delta_t", "group", "fvalue")
vals2$fvalue <- as.numeric(vals2$fvalue)

# Produce plots
# Fix order
prd_all <- transform(prd_all, group=factor(group, levels=unique(group)))
vals2 <- transform(vals2, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c( "darkred","darkgreen","darkblue") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21,21)

# Abundance plots
p_abundance <- ggplot(vals2, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none", 
        axis.title.x=element_blank(), axis.text.x=element_blank(),
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups", values = shapescheme) +
  geom_line(data=prd_all, aes(delta_t, exp(fit), colour=factor(group)), size=1.6) +
  geom_ribbon(data = prd_all, aes(delta_t, ymin = exp(lci), ymax = exp(uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2, aes(x=delta_t, y=exp(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous(trans = log_trans(), breaks = c(0.1, 1, 10, 100, 1000)) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))
labs(x=NULL, y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))  # To suppress X-axis for combination
p_abundance

# Linear regression (2nd order polynomial) for species richness

# Rheophilics
fit_rheo_sp <- lm(rheo_spec ~ delta_t)
summary(fit_rheo_sp)
anova(fit_rheo_sp)
qqnorm(fit_rheo_sp$residuals)
shapiro.test(fit_rheo_sp$residuals)
prd_rheo_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo_sp <- predict(fit_rheo_sp, newdata = prd_rheo_sp, se.fit = TRUE)

prd_rheo_sp$lci <- err_rheo_sp$fit - 1.96 * err_rheo_sp$se.fit
prd_rheo_sp$fit <- err_rheo_sp$fit
prd_rheo_sp$uci <- err_rheo_sp$fit + 1.96 * err_rheo_sp$se.fit
prd_rheo_sp$group <- "Rheophilics"

# Eurytopic fish - species diversity
fit_eury_sp <- lm(eury_spec ~ delta_t + I(delta_t^2))
summary(fit_eury_sp)
anova(fit_eury_sp)
qqnorm(fit_eury_sp$residuals)
shapiro.test(fit_eury_sp$residuals)
prd_eury_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury_sp <- predict(fit_eury_sp, newdata = prd_eury_sp, se.fit = TRUE)

prd_eury_sp$lci <- err_eury_sp$fit - 1.96 * err_eury_sp$se.fit
prd_eury_sp$fit <- err_eury_sp$fit
prd_eury_sp$uci <- err_eury_sp$fit + 1.96 * err_eury_sp$se.fit
prd_eury_sp$group <- "Eurytopics"

# Limnophilic fish - species diversity
fit_limno_sp <- lm(limno_spec ~ delta_t + I(delta_t^2))
summary(fit_limno_sp)
anova(fit_limno_sp)
qqnorm(fit_limno_sp$residuals)
shapiro.test(fit_limno_sp$residuals)
prd_limno_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno_sp <- predict(fit_limno_sp, newdata = prd_limno_sp, se.fit = TRUE)

#prd_limno_sp$lci <- err_limno_sp$fit - 1.96 * err_limno_sp$se.fit
#prd_limno_sp$fit <- err_limno_sp$fit
#prd_limno_sp$uci <- err_limno_sp$fit + 1.96 * err_limno_sp$se.fit
prd_limno_sp$group <- "Limnophilics"

# Merge the output values
prd_all_sp <- rbind(prd_rheo_sp) # Only pick the significant ecological groups
prd_all_sp <- na.omit(prd_all_sp) # Delete rows with NA

# Dataframe with original data
vals1_sp <- data_complete[,c("Delta_t","Spec_Rheo2","Spec_Eury2","Spec_Limno2")]
names(vals1_sp) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
id <- c("delta_t")
vals2_sp <- na.omit(melt(vals1_sp, id.vars=id))
names(vals2_sp) <- c("delta_t","group", "fvalue")
vals2_sp$fvalue <- as.numeric(vals2_sp$fvalue)

# Produce plots
# Fix order
prd_all_sp <- transform(prd_all_sp, group=factor(group, levels=unique(group)))
vals2_sp <- transform(vals2_sp, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c( "darkred","darkgreen","darkblue") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21,21)

p_spec <- ggplot(vals2_sp, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none",
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all_sp, aes(delta_t, (fit), colour=factor(group)), size=1.5) +
  geom_ribbon(data = prd_all_sp, aes(delta_t, ymin = (lci), ymax = (uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2_sp, aes(x=delta_t, y=(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  #scale_y_continuous(labels = scales::number_format(accuracy = 1)) + 
  scale_y_continuous(breaks=c(0,4,8,12,16)) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y="Species richness") +
  theme(strip.text.x = element_blank()) + theme(strip.background = element_blank()) # to suppress strips for combination
p_spec

# Combine graphs
library(cowplot)
cowplot::plot_grid(p_abundance, p_spec, align = "v", ncol = 1, rel_heights = c(0.46, 0.54))



### Load original dataset - only recent data
data_complete <- read.csv(file="master_datafile.csv")
data_complete2 <- data_complete[c(17:47),]
# Chosing regression parameters

# Age of channel
delta_t <- data_complete2$Delta_t

# Abundances
data_complete2$logrheo2    <- log(data_complete2$Rheo2)
data_complete2$logeury2    <- log(data_complete2$Eury2)
data_complete2$loglimno2   <- log(data_complete2$Limno2)
data_complete2$logallfish2   <- log(data_complete2$Allfish)

rheo    <- data_complete2$logrheo2
eury    <- data_complete2$logeury2
limno   <- data_complete2$loglimno2
#fish   <- data_complete2$logallfish2

# Species richness
rheo_spec <- data_complete2$Spec_Rheo2
eury_spec <- data_complete2$Spec_Eury2
limno_spec <- data_complete2$Spec_Limno2
#fish_spec <- data_complete2$Spec_Allfish

# Linear regression (2nd order polynomial) for abundances

# Rheophilics
fit_rheo <- lm(rheo ~ delta_t + I(delta_t^2))
summary(fit_rheo)
anova(fit_rheo)
qqnorm(fit_rheo$residuals)
shapiro.test(fit_rheo$residuals)
prd_rheo <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo <- predict(fit_rheo, newdata = prd_rheo, se.fit = TRUE)

prd_rheo$lci <- err_rheo$fit - 1.96 * err_rheo$se.fit
prd_rheo$fit <- err_rheo$fit
prd_rheo$uci <- err_rheo$fit + 1.96 * err_rheo$se.fit
prd_rheo$group <- "Rheophilics"

# Eurytopics
fit_eury <- lm(eury ~ delta_t + I(delta_t^2))
summary(fit_eury)
anova(fit_eury)
qqnorm(fit_eury$residuals)
shapiro.test(fit_eury$residuals)
prd_eury <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury <- predict(fit_eury, newdata = prd_eury, se.fit = TRUE)

#prd_eury$lci <- err_eury$fit - 1.96 * err_eury$se.fit
#prd_eury$fit <- err_eury$fit
#prd_eury$uci <- err_eury$fit + 1.96 * err_eury$se.fit
prd_eury$group <- "Eurytopics"

# Limnophilics
fit_limno <- lm(limno ~ delta_t + I(delta_t^2))
summary(fit_limno)
anova(fit_limno)
qqnorm(fit_limno$residuals)
shapiro.test(fit_limno$residuals)
prd_limno <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno <- predict(fit_limno, newdata = prd_limno, se.fit = TRUE)

#prd_limno$lci <- err_limno$fit - 1.96 * err_limno$se.fit
#prd_limno$fit <- err_limno$fit
#prd_limno$uci <- err_limno$fit + 1.96 * err_limno$se.fit
prd_limno$group <- "Limnophilics"

# Merge the output values
prd_all <- rbind(prd_rheo) # Only pick the significant ecological groups
prd_all <- na.omit(prd_all) # Delete rows with NA

# Dataframe with original data
vals1 <- data_complete2[,c("Delta_t","logrheo2","logeury2","loglimno2")]
names(vals1) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
id <- c("delta_t")
vals2 <- na.omit(melt(vals1, id.vars=id))
names(vals2) <- c("delta_t", "group", "fvalue")
vals2$fvalue <- as.numeric(vals2$fvalue)

# Produce plots
# Fix order
prd_all <- transform(prd_all, group=factor(group, levels=unique(group)))
vals2 <- transform(vals2, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("darkblue","darkred","darkgreen") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21,21)

# Abundance plots
p_abundance <- ggplot(vals2, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none", 
        axis.title.x=element_blank(), axis.text.x=element_blank(),
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups", values = shapescheme) +
  #geom_line(data=prd_all, aes(delta_t, exp(fit), colour=factor(group)), size=1.6) +
  #geom_ribbon(data = prd_all, aes(delta_t, ymin = exp(lci), ymax = exp(uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2, aes(x=delta_t, y=exp(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous(trans = log_trans(), breaks = c(0.1, 1, 10, 100, 1000)) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))
labs(x=NULL, y=expression(paste("Abundance"," ","(fish per 100",m^2,")")))  # To suppress X-axis for combination
p_abundance

# Linear regression (2nd order polynomial) for species richness

# Rheophilics
fit_rheo_sp <- lm(rheo_spec ~ delta_t)
summary(fit_rheo_sp)
anova(fit_rheo_sp)
qqnorm(fit_rheo_sp$residuals)
shapiro.test(fit_rheo_sp$residuals)
prd_rheo_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_rheo_sp <- predict(fit_rheo_sp, newdata = prd_rheo_sp, se.fit = TRUE)

prd_rheo_sp$lci <- err_rheo_sp$fit - 1.96 * err_rheo_sp$se.fit
prd_rheo_sp$fit <- err_rheo_sp$fit
prd_rheo_sp$uci <- err_rheo_sp$fit + 1.96 * err_rheo_sp$se.fit
prd_rheo_sp$group <- "Rheophilics"

# Eurytopic fish - species diversity
fit_eury_sp <- lm(eury_spec ~ delta_t + I(delta_t^2))
summary(fit_eury_sp)
anova(fit_eury_sp)
qqnorm(fit_eury_sp$residuals)
shapiro.test(fit_eury_sp$residuals)
prd_eury_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_eury_sp <- predict(fit_eury_sp, newdata = prd_eury_sp, se.fit = TRUE)

prd_eury_sp$lci <- err_eury_sp$fit - 1.96 * err_eury_sp$se.fit
prd_eury_sp$fit <- err_eury_sp$fit
prd_eury_sp$uci <- err_eury_sp$fit + 1.96 * err_eury_sp$se.fit
prd_eury_sp$group <- "Eurytopics"

# Limnophilic fish - species diversity
fit_limno_sp <- lm(limno_spec ~ delta_t + I(delta_t^2))
summary(fit_limno_sp)
anova(fit_limno_sp)
qqnorm(fit_limno_sp$residuals)
shapiro.test(fit_limno_sp$residuals)
prd_limno_sp <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_limno_sp <- predict(fit_limno_sp, newdata = prd_limno_sp, se.fit = TRUE)

#prd_limno_sp$lci <- err_limno_sp$fit - 1.96 * err_limno_sp$se.fit
#prd_limno_sp$fit <- err_limno_sp$fit
#prd_limno_sp$uci <- err_limno_sp$fit + 1.96 * err_limno_sp$se.fit
prd_limno_sp$group <- "Limnophilics"

# Merge the output values
prd_all_sp <- rbind(prd_rheo_sp) # Only pick the significant ecological groups
prd_all_sp <- na.omit(prd_all_sp) # Delete rows with NA

# Dataframe with original data
vals1_sp <- data_complete2[,c("Delta_t","Spec_Rheo2","Spec_Eury2","Spec_Limno2")]
names(vals1_sp) <- c("delta_t", "Rheophilics", "Eurytopics", "Limnophilics")
id <- c("delta_t")
vals2_sp <- na.omit(melt(vals1_sp, id.vars=id))
names(vals2_sp) <- c("delta_t","group", "fvalue")
vals2_sp$fvalue <- as.numeric(vals2_sp$fvalue)

# Produce plots
# Fix order
prd_all_sp <- transform(prd_all_sp, group=factor(group, levels=unique(group)))
vals2_sp <- transform(vals2_sp, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("darkblue","darkred","darkgreen") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21,21)

p_spec <- ggplot(vals2_sp, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(2)), legend.position="none",
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  #geom_line(data=prd_all_sp, aes(delta_t, (fit), colour=factor(group)), size=1.5) +
  #geom_ribbon(data = prd_all_sp, aes(delta_t, ymin = (lci), ymax = (uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2_sp, aes(x=delta_t, y=(fvalue),  shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  #scale_y_continuous(labels = scales::number_format(accuracy = 1)) + 
  scale_y_continuous(breaks=c(0,4,8,12,16)) +
  scale_x_continuous(limits = c(0, 31), expand = c(0, 0)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y="Species richness") +
  theme(strip.text.x = element_blank()) + theme(strip.background = element_blank()) # to suppress strips for combination
p_spec

# Combine graphs
library(cowplot)
cowplot::plot_grid(p_abundance, p_spec, align = "v", ncol = 1, rel_heights = c(0.46, 0.54))

