### Habitat-fish data analysis

### Title
# 30 years of large river restoration: how long do restored floodplain channels 
# remain suitable for targeted rheophilic fish in the lower river Rhine? 

### Authors
# T. Stoffers, F.P.L. Collas, G.W. Geerling, A.D. Buijse, L.H. Jans, 
# N. van Kessel, J.A.J. Verreth,  L.A.J. Nagelkerke

# 1.  Housekeeping ----

# Set path for packages
.libPaths('C:/Software/R')

# Set working directory
#setwd("m:\\My Documents\\Projecten\\Twan\\Analyse") #Leo
setwd("C:\\Users\\Stoff004\\OneDrive - WageningenUR\\2020 30 jaar geulen paper\\Analyse\\Analyse R") #Twan

# Empty the environment
remove(list=ls(all=TRUE))  #remove all objects

# load packages
source("HighstatLibV13.R")
library(plyr)  
library(dplyr)
library(corrplot)
library(vegan)
library(reshape2)
library(ggplot2)
library(MASS)
library(tidyr)
library(scales)
library(psych)
library(cowplot)
library(gridExtra)
library(grid)
library(devtools)
library(mclust)

# Read raw data file
data <- read.csv(file="Stoffers2020_final_data.csv")
data <- data[,-c(1)] # remove first column

# Subsetting
fish_abundance <- data[c(2,3,5,34:36)]
fish_richness <- data[c(2,3,5,41:43)]
habitat <- data[c(2,3,5,6:22)]
summary(habitat)

# 2.  Habitat correlation check ---- 

# Calculate 'Shoreline index' with: (shore_length^2/surface_area) to to able to remove 'distance parameters'
habitat$Shoreline_index <- (habitat$Shore_length)/(habitat$Surface_area)

# Correlation between environmental variables to remove habitat variables that are heavily correlated
habitat$Shore_vegetation <- MyStd(habitat$Shore_vegetation)
habitat$Water_flow <- MyStd(habitat$Water_flow)
habitat$Shoreline_index <- MyStd(habitat$Shoreline_index)
names(habitat)[14]<-paste("Aquatic_vegetation")
names(habitat)[15]<-paste("Substratum_size")
names(habitat)[16]<-paste("Sand_deposition")
names(habitat)[17]<-paste("Silt_deposition")

corrplot(cor((habitat[c(4:21)]), method = "kendall"), method = "number", type = "lower", 
         bg = "white", tl.cex = 0.8, number.cex = 0.5, tl.col = "black") #met waardes

# High correlations for:
# Water flow - connectivity
# Length - Width
# Length - shore_length
# Shore length - Habitat_heterogeneity
# Shore_length- Surface_area
# Inlet_ type - Water_flow
# Inflow_angle - Water_flow



# Remove high correlation parameters and distance parameters:
# 'Connectivity', 'Length', 'Width', 'Shore_length', 'Surface_area', 'Inlet_type' and 'Inflow_angle' 
habitat2 <- habitat[-c(4,8:11,19,20)]
summary(habitat2)
corrplot(cor((habitat2[c(4:14)]), method = "kendall"), method = "number", type = "lower", 
         bg = "white", tl.cex = 0.8, number.cex = 0.5, tl.col = "black")
# No major correlations > 0.6

# Clustering environmental variables
cor_env1 <- cor(habitat2[c(4:14)], use="complete.obs", method="kendall")
dist1 <- as.dist(1-cor(cor_env1, use="complete.obs", method = "kendall"))
plot(hclust(dist1, method = "ward.D2"))
clust <- hclust(dist1, method = "ward.D2")
rect.hclust(clust, 4)

# 3.  PCA Habitat and location data ---- 

# Log standarisation of continuous habitat data for PCA
#min_value1 <- min(habitat2$Shore_vegetation[which(habitat2$Shore_vegetation!=0)])
#habitat2$Shore_vegetation <- log(habitat2$Shore_vegetation + 0.5 * min_value1) # log(difference + half of the lowest non-zero value)
#min_value2 <- min(habitat2$Water_flow[which(habitat2$Water_flow!=0)])
#habitat2$Water_flow <- log(habitat2$Water_flow + 0.5 * min_value2) # log(difference + half of the lowest non-zero value)
#habitat2$Shoreline_index <- log(habitat2$Shoreline_index)

habitatPCA <- rda(habitat2[c(4:14)]) 
habitatPCA
summary(habitatPCA)
plot(habitatPCA)
biplot(habitatPCA, scaling = -1)

#  Extract biplot data
biplot_location <- habitatPCA$CA$u[,1:2] # extract x-y coordinates locations of first 2 PCA axes
biplot_location2 <- merge(biplot_location, habitat2[,c(1:3)], by="row.names") # add site information for plot
biplot_environment <- habitatPCA$CA$v[,1:2] # location data

#write.csv(biplot_location2, file="locationPCA.csv")
#write.csv(biplot_environment, file="habitatPCA.csv")

# 4.  Plot channel age against PCA axis 1-2 values ----

PCA_data <- merge(biplot_location2[-c(1)], fish_abundance[-c(3)], by=c("Name", "Delta_t"))

PC1 <- PCA_data$PC1
PC2 <- PCA_data$PC2
rheo <- PCA_data$Rheo2

delta_t <- PCA_data$Delta_t

# PCA1 regression analysis
fit_PC1 <- lm(PC1 ~ delta_t)
summary(fit_PC1)
anova(fit_PC1)
qqnorm(fit_PC1$residuals)
shapiro.test(fit_PC1$residuals)
prd_PC1 <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_PC1 <- predict(fit_PC1, newdata = prd_PC1, se.fit = TRUE)

prd_PC1$lci <- err_PC1$fit - 1.96 * err_PC1$se.fit
prd_PC1$fit <- err_PC1$fit
prd_PC1$uci <- err_PC1$fit + 1.96 * err_PC1$se.fit
prd_PC1$group <- "PC1"

# PCA2
fit_PC2 <- lm(PC2 ~ delta_t + I(delta_t^2))
summary(fit_PC2)
anova(fit_PC2)
qqnorm(fit_PC2$residuals)
shapiro.test(fit_PC2$residuals)
prd_PC2 <- data.frame(delta_t = seq(from = range(delta_t)[1], to = range(delta_t)[2], length.out = 48))
err_PC2 <- predict(fit_PC2, newdata = prd_PC2, se.fit = TRUE)

prd_PC2$lci <- err_PC2$fit - 1.96 * err_PC2$se.fit
prd_PC2$fit <- err_PC2$fit
prd_PC2$uci <- err_PC2$fit + 1.96 * err_PC2$se.fit
prd_PC2$group <- "PC2"

# Dataframe with original data
vals1 <- PCA_data[,c("Delta_t","PC1","PC2")]
names(vals1) <- c("Delta_t","PC1","PC2")
id <- c("Delta_t")
vals2 <- na.omit(melt(vals1, id.vars=id))
names(vals2) <- c("Delta_t", "group", "fvalue")
vals2$fvalue <- as.numeric(vals2$fvalue)

# Produce plots
prd_all <- rbind(prd_PC1, prd_PC2)
prd_all <- na.omit(prd_all) # Delete rows with NA

# Fix order
prd_all <- transform(prd_all, group=factor(group, levels=unique(group)))
vals2 <- transform(vals2, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("black", "black") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21)

# Habitat-age plots
hab_age <- ggplot(prd_all, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(2)), 
        strip.text=element_text(size=rel(1.5)), legend.position="none", 
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all, aes(delta_t, fit, colour=factor(group)), size=1.5) +
  geom_ribbon(data = prd_all, aes(delta_t, ymin = lci, ymax = uci, fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2, aes(x=Delta_t, y=fvalue, shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous() +
  scale_x_continuous(limits = c(0, 30)) +
  labs(x=expression(paste("Age"," ",(Delta*t))), y="PC value")
hab_age

# 5a. Plot channel age against rheophilic abundances ----

PCA_data <- merge(biplot_location2[-c(1)], fish_abundance[-c(3)], by=c("Name", "Delta_t"))

PC1 <- PCA_data$PC1
PC2 <- PCA_data$PC2
rheo <- PCA_data$Rheo2
rheo <- log(PCA_data$Rheo2)

delta_t <- PCA_data$Delta_t

# PCA1 regression analysis
fit_rheo1 <- lm(rheo ~ PC1)
summary(fit_rheo1)
anova(fit_rheo1)
qqnorm(fit_rheo1$residuals)
shapiro.test(fit_rheo1$residuals)
prd_rheo1 <- data.frame(PC1 = seq(from = range(PC1)[1], to = range(PC1)[2], length.out = 48))
err_rheo1 <- predict(fit_rheo1, newdata = prd_rheo1, se.fit = TRUE)

prd_rheo1$lci <- err_rheo1$fit - 1.96 * err_rheo1$se.fit
prd_rheo1$fit <- err_rheo1$fit
prd_rheo1$uci <- err_rheo1$fit + 1.96 * err_rheo1$se.fit
prd_rheo1$group <- "PC1"

# PCA2
fit_rheo2 <- lm(rheo ~ PC2)
summary(fit_rheo2)
anova(fit_rheo2)
qqnorm(fit_rheo2$residuals)
shapiro.test(fit_rheo2$residuals)
prd_rheo2 <- data.frame(PC2 = seq(from = range(PC2)[1], to = range(PC2)[2], length.out = 48))
err_rheo2 <- predict(fit_rheo2, newdata = prd_rheo2, se.fit = TRUE)

prd_rheo2$lci <- err_rheo2$fit - 1.96 * err_rheo2$se.fit
prd_rheo2$fit <- err_rheo2$fit
prd_rheo2$uci <- err_rheo2$fit + 1.96 * err_rheo2$se.fit
prd_rheo2$group <- "PC2"

# Dataframe with original data
vals1 <- PCA_data[,c("Rheo2","PC1","PC2")]
names(vals1) <- c("Rheo","PC1","PC2")
id <- c("Rheo")
vals2 <- na.omit(melt(vals1, id.vars=id))
names(vals2) <- c("Rheo", "group", "fvalue")
vals2$fvalue <- as.numeric(vals2$fvalue)

# Produce plots
colnames(prd_rheo1)[1] <- "PC"
colnames(prd_rheo2)[1] <- "PC"
prd_all <- rbind(prd_rheo1, prd_rheo2)
prd_all <- na.omit(prd_all) # Delete rows with NA

# Fix order
prd_all <- transform(prd_all, group=factor(group, levels=unique(group)))
vals2 <- transform(vals2, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("darkblue", "darkblue") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21)

# Habitat-age plots
hab_rheo_abun <- ggplot(prd_all, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.4)), axis.title=element_text(size=rel(1.5)), 
        strip.text=element_text(size=rel(2)), legend.position="none", 
        axis.title.x=element_blank(), axis.text.x=element_blank(),
        panel.spacing = unit(1, "lines")) +
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all, aes(PC, exp(fit), colour=factor(group)), size=1.5) +
  geom_ribbon(data=prd_all, aes(PC, ymin = exp(lci), ymax = exp(uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2, aes(x=fvalue, y=Rheo, shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous(trans = log_trans(), breaks = c(0.1, 1, 10, 100, 1000)) +
  scale_x_continuous() +
  labs(x="PC value", y=expression(paste("Abundance"," ","(rheophilic fish per 100",m^2,")")))
hab_rheo_abun


# 5b. Plot channel age against rheophilic species richness ----
PCA_data_spec <- merge(biplot_location2[-c(1)], fish_richness[-c(3)], by=c("Name", "Delta_t"))

PC1 <- PCA_data_spec$PC1
PC2 <- PCA_data_spec$PC2
rheo <- PCA_data_spec$Spec_Rheo2

delta_t <- PCA_data_spec$Delta_t

# PCA1 regression analysis
fit_rheo1 <- lm(rheo ~ PC1)
summary(fit_rheo1)
anova(fit_rheo1)
qqnorm(fit_rheo1$residuals)
shapiro.test(fit_rheo1$residuals)
prd_rheo1 <- data.frame(PC1 = seq(from = range(PC1)[1], to = range(PC1)[2], length.out = 48))
err_rheo1 <- predict(fit_rheo1, newdata = prd_rheo1, se.fit = TRUE)

prd_rheo1$lci <- err_rheo1$fit - 1.96 * err_rheo1$se.fit
prd_rheo1$fit <- err_rheo1$fit
prd_rheo1$uci <- err_rheo1$fit + 1.96 * err_rheo1$se.fit
prd_rheo1$group <- "PC1"

# PCA2
fit_rheo2 <- lm(rheo ~ PC2)
summary(fit_rheo2)
anova(fit_rheo2)
qqnorm(fit_rheo2$residuals)
shapiro.test(fit_rheo2$residuals)
prd_rheo2 <- data.frame(PC2 = seq(from = range(PC2)[1], to = range(PC2)[2], length.out = 48))
err_rheo2 <- predict(fit_rheo2, newdata = prd_rheo2, se.fit = TRUE)

prd_rheo2$lci <- err_rheo2$fit - 1.96 * err_rheo2$se.fit
prd_rheo2$fit <- err_rheo2$fit
prd_rheo2$uci <- err_rheo2$fit + 1.96 * err_rheo2$se.fit
prd_rheo2$group <- "PC2"

# Dataframe with original data
vals1 <- PCA_data_spec[,c("Spec_Rheo2","PC1","PC2")]
names(vals1) <- c("Rheo","PC1","PC2")
id <- c("Rheo")
vals2 <- na.omit(melt(vals1, id.vars=id))
names(vals2) <- c("Rheo", "group", "fvalue")
vals2$fvalue <- as.numeric(vals2$fvalue)

# Produce plots
colnames(prd_rheo1)[1] <- "PC"
colnames(prd_rheo2)[1] <- "PC"
prd_all <- rbind(prd_rheo1, prd_rheo2)
prd_all <- na.omit(prd_all) # Delete rows with NA

# Fix order
prd_all <- transform(prd_all, group=factor(group, levels=unique(group)))
vals2 <- transform(vals2, group=factor(group, levels=unique(group)))

# Colour and shape schemes
colscheme <- c("darkblue", "darkblue") # colours vary depending on the nr of groups with significant patterns
shapescheme <- c(21,21)

# Habitat-age plots
hab_rheo_spec <- ggplot(prd_all, aes(colour=factor(group))) + 
  facet_grid(~group, scales="free") +
  theme_bw() +
  theme(plot.title = element_text(size = rel(2), face="bold"), 
        axis.text=element_text(size=rel(1.5)), axis.title=element_text(size=rel(1.5)), 
        strip.text=element_text(size=rel(1.5)), legend.position="none", 
        panel.spacing = unit(1, "lines")) +  
  scale_colour_manual(name = "groups",values = colscheme, aesthetics=c("colour","fill"))  +
  scale_shape_manual(name = "groups",values = shapescheme) +  
  geom_line(data=prd_all, aes(PC, fit, colour=factor(group)), size=1.5) +
  geom_ribbon(data=prd_all, aes(PC, ymin = (lci), ymax = (uci), fill=factor(group)), alpha=.3, colour=NA) + 
  geom_point(data=vals2, aes(x=fvalue, y=Rheo, shape=factor(group), fill=factor(group), alpha=0.4), colour="black", size=4) +
  scale_y_continuous(breaks=c(0,2,4,6)) +
  scale_x_continuous() +
  labs(x="PC value", y="Rheophilic species richness") +
  theme(strip.text.x = element_blank()) + theme(strip.background = element_blank()) # to suppress strips for combination

hab_rheo_spec

# Combine graphs
library(cowplot)
cowplot::plot_grid(hab_rheo_abun, hab_rheo_spec, align = "v", ncol = 1, rel_heights = c(0.46, 0.54))


# 6a. CCA analysis: abundance data [In paper] ----

# Square root transformation of abundance data
fish_abundance <- data[c(2,3,5,34:36)]
fish_abundance$sqrtRheo2 <- sqrt(fish_abundance$Rheo2) # Square root transformation count data
fish_abundance$sqrtEury2 <- sqrt(fish_abundance$Eury2) # Square root transformation count data
fish_abundance$sqrtLimno2 <- sqrt(fish_abundance$Limno2) # Square root transformation count data
sqrt_fish_abundance <- fish_abundance[c(7:9)] # select only fishy columns
fish_abundance1 <- fish_abundance[c(4:6)]

# Select habitat data
habitat3 <- habitat2[-c(1:3)]

# Full CCA model
CCA <- cca(sqrt_fish_abundance ~ Water_flow + Mean_flow + Depth + Shore_vegetation + Shore_steepness +
             Aquatic_vegetation + Substratum_size + Sand_deposition + Silt_deposition + Habitat_heterogeneity + Shoreline_index,
           data=habitat3, display=c('sp', 'lc', 'cn'))
summary(CCA)
screeplot(CCA)
vif.cca(CCA) # VIFs are high

# Remove: Water_flow + Siltation + Shore_steepness
CCA2 <- cca(sqrt_fish_abundance ~ Mean_flow + Substratum_size + Depth + Shore_vegetation +
               Sand_deposition + Habitat_heterogeneity + Shoreline_index + Aquatic_vegetation,
            data=habitat3, display=c('sp', 'lc', 'cn'))
summary(CCA2)
screeplot(CCA2)
vif.cca(CCA2) # VIFs under 2.2 now. Good!
plot(CCA2, scaling=2, display=c('sp', 'lc', 'cn'), main='Triplot CCA matrix ~ env -scaling 1') # Scaling 1: species scores scaled to relative eigenvalues, sites are weighted averages of the species 

anova(CCA2) # Model is significant: p = 0.038
anova(CCA2, by="term", step=999) # The significance of individual tems (permutation test) - Type I test
# Mean_flow, Substrate, Waterplants
anova(CCA2, by="axis", step=999) # PC1 axis is significant

# Produce output in .csv for use in Excel: Extract biplot data
biplot_location <- CCA2$CCA$u[,1:2]
biplot_location <- as.data.frame(biplot_location)
biplot_location$carnames <- rownames(biplot_location)
rownames(biplot_location) <- 1:nrow(biplot_location)
biplot_location <- biplot_location[c(1,2)]

biplot_location2 <- merge(biplot_location, habitat2[,c(1:3)], by="row.names") # Add site information for plot
biplot_fish <- CCA2$CCA$v[,1:2]
biplot_environment <- CCA2$CCA$biplot

#write.csv(biplot_location2, file="CCA_location_plot.csv")
#write.csv(biplot_fish, file="CCA_fish_plot.csv")
#write.csv(biplot_environment, file="CCA_habitat_plot.csv")


# 6b. CCA analysis: species richness data [In paper] ----

# Richness data
fish_richness <- data[c(2,3,5,41:43)]
richness <- fish_richness[c(4:6)]

# Select habitat data
habitat3 <- habitat2[-c(1:3)]

# Full CCA model
CCA_spec <- cca(richness ~ Water_flow + Mean_flow + Depth + Shore_vegetation + Shore_steepness +
                  Aquatic_vegetation + Substratum_size + Sand_deposition + Silt_deposition + Habitat_heterogeneity + Shoreline_index,
                data=habitat3, display=c('sp', 'lc', 'cn'))
summary(CCA_spec)
screeplot(CCA_spec)
vif.cca(CCA_spec) # VIFs are high

# Remove: Water_flow
CCA2_spec <- cca(richness ~ Water_flow + Substratum_size + Depth + Shore_vegetation + Shore_steepness +
                   Aquatic_vegetation + Silt_deposition + Sand_deposition + Shoreline_index,
                 data=habitat3, display=c('sp', 'lc', 'cn'))
summary(CCA2_spec)
screeplot(CCA2_spec)
vif.cca(CCA2_spec) # VIFs under 2.2 now. Good!
plot(CCA2_spec, scaling=2, display=c('sp', 'lc', 'cn'), main='Triplot CCA matrix ~ env -scaling 1') # Scaling 1: species scores scaled to relative eigenvalues, sites are weighted averages of the species 

anova(CCA2_spec) # Model is significant: p = 0.037
anova(CCA2_spec, by="term", step=999) # The significance of individual tems (permutation test) - Type I test
# Mean_flow, Substrate, Waterplants
anova(CCA2_spec, by="axis", step=999) # PC1 axis is significant

# Produce output in .csv for use in Excel: Extract biplot data
biplot_location <- CCA2_spec$CCA$u[,1:2]
biplot_location <- as.data.frame(biplot_location)
biplot_location$carnames <- rownames(biplot_location)
rownames(biplot_location) <- 1:nrow(biplot_location)
biplot_location <- biplot_location[c(1,2)]

biplot_location2 <- merge(biplot_location, habitat2[,c(1:3)], by="row.names") # Add site information for plot
biplot_fish <- CCA2_spec$CCA$v[,1:2]
biplot_environment <- CCA2_spec$CCA$biplot

#write.csv(biplot_location2, file="CCA_location_spec_plot.csv")
#write.csv(biplot_fish, file="CCA_fish_spec_plot.csv")
#write.csv(biplot_environment, file="CCA_habitat_spec_plot.csv")