### MWTL data analysis (long-term trends) 

### Title
# 30 years of large river restoration: how long do restored floodplain channels 
# remain suitable for targeted rheophilic fish in the lower river Rhine? 

### Authors
# T. Stoffers, F.P.L. Collas, G.W. Geerling, A.D. Buijse, L.H. Jans, 
# N. van Kessel, J.A.J. Verreth,  L.A.J. Nagelkerke

# 1.  Housekeeping ----

# Set path for packages
.libPaths('C:/Software/R')

# Set working directory
setwd("C:\\Users\\Stoff004\\OneDrive - WageningenUR\\2020 30 jaar geulen paper\\Analyse\\Analyse R") #Twan

# Empty the environment
remove(list=ls(all=TRUE))  #remove all objects

# load packages
library(plyr)  
library(dplyr)
library(reshape2)
library(ggplot2)
library(scales)
library(cowplot)
library(data.table)
library(stats)

# 2. Data selection and cleaning ----
Achtergrond  <- read.csv(file="Achtergrond.csv", sep=";")
Phosphate    <- read.csv(file="PhosphateYear.csv", sep=";")
Temperature  <- read.csv(file="TemperatureYear.csv", sep=";")
Afvoer       <- read.csv(file="Afvoer_Lobith_40jaar.csv", sep=",")
Oxygen       <- read.csv(file="oxygenYear.csv", sep=";")

# Create title textbox element function
element_textbox <- function(...) {
  el <- element_text(...)
  class(el) <- c("element_textbox", class(el))
  el
}
element_grob.element_textbox <- function(element, ...) {
  text_grob <- NextMethod()
  rect_grob <- element_grob(calc_element("strip.background", theme_bw()))
  
  ggplot2:::absoluteGrob(
    grid::gList(
      element_grob(calc_element("strip.background", theme_bw())),
      text_grob
    ),
    height = grid::grobHeight(text_grob), 
    width = grid::unit(1, "npc")
  )
}


# 3. Producing graphs [In paper] ----

#Phosphate
Phosphate  <- Phosphate[-c(1)]
colnames(Phosphate)[1] <- "Jaar"
Phosphate$Jaar <- as.factor(Phosphate$Jaar)

PhosphateFig <- ggplot(Phosphate) +
  theme_bw() +
  theme(plot.title=element_textbox(hjust=0.5,size=20,margin=margin(t=5,b=5)), 
        axis.text=element_text(size=rel(1.5), colour = "black"), 
        axis.text.x=element_blank(),
        axis.title=element_text(size=rel(1.5), colour ="black"),
        axis.title.x=element_blank(),
        legend.position="none",
        axis.ticks = element_line(colour = "black", size = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        panel.grid.major = element_line(colour = "gray98"),
        panel.grid.minor = element_line(colour = "gray98"),
        plot.margin=unit(c(0.3,0.5,0.3,0.3),"cm")) +
  #geom_ribbon(data=Phosphate, aes(Jaar, ymin = X2.5, ymax = X97.5, group=1), alpha=0.4, fill="snow3") +
  #geom_line(data=Phosphate, aes(Jaar, median, group=1), colour="snow4", size=0.8, alpha=0.6) +
  geom_pointrange(data=Phosphate, aes(Jaar, median, ymin = X2.5, ymax= X97.5), size = 1, alpha=1, colour="black") +
  geom_point(data=Phosphate, aes(Jaar, median, group=1), colour="black", size=4, alpha=1) +
  scale_x_discrete() +
  scale_y_continuous(limits=c(0, 0.25),breaks=c(0,0.1,0.2,0.3),labels=c(0,0.1,0.2,0.3)) +
  labs(x ="Year", y ="Phosphate\n(mg/l)", title ="Phosphate levels")

PhosphateFig

# Temperature
Temperature  <- read.csv(file="Temperature_raw_new.csv", sep=",")
Temperature <- Temperature %>%
  group_by(Month, Year) %>%
  summarise_each(funs(mean))
  
Temperature2  <- read.csv(file="Temperature_raw_new2.csv", sep=",")
Temperature2 <- Temperature2 %>%
  group_by(WAARNEMINGDATUM) %>%
  summarise_each(funs(mean))
Temperature2 <- Temperature2 %>%
  group_by(Month, Year) %>%
  summarise_each(funs(mean))
Temp <- rbind(Temperature,Temperature2)
Temp <- Temp[c(2,6)]

Temp2 <- Temp%>%
  group_by(Year)%>% 
  summarise(X2.5=quantile(TEMP_CORR, probs = 0.025),
            X97.5=quantile(TEMP_CORR, probs = 0.975),
            Mean=mean(TEMP_CORR), Max=max(TEMP_CORR), Min=min(TEMP_CORR), Median=median(TEMP_CORR), Std=sd(TEMP_CORR)) 


colnames(Temp2)[1] <- "Jaar"
Temp2$Jaar <- as.factor(Temp2$Jaar)

TemperatureFig<- ggplot(Temp2) +
  theme_bw() +
  theme(plot.title=element_textbox(hjust=0.5,size=20,margin=margin(t=5,b=5)), 
        axis.text=element_text(size=rel(1.5), colour = "black"), 
        axis.text.x=element_blank(),
        axis.title=element_text(size=rel(1.5), colour ="black"),
        axis.title.x=element_blank(),
        legend.position="none",
        axis.ticks = element_line(colour = "black", size = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        panel.grid.major = element_line(colour = "gray98"),
        panel.grid.minor = element_line(colour = "gray98"),
        plot.margin=unit(c(0.3,0.5,0.3,0.3),"cm")) +
  #geom_ribbon(data=Temp2, aes(Jaar, ymin = X2.5, ymax = X97.5, group=1), alpha=0.4, fill="snow3") +
  #geom_line(data=Temp2, aes(Jaar, Median, group=1), colour="snow4", size=0.8, alpha=0.6) +
  geom_pointrange(data=Temp2, aes(Jaar, Median, ymin = X2.5, ymax= X97.5), size = 1, alpha=1, colour="black") +
  geom_point(data=Temp2, aes(Jaar, Median, group=1), colour="black", size=4, alpha=1) +
  scale_x_discrete() +
  scale_y_continuous(limits=c(0, 30),breaks=c(0,10,20,30),labels=c(0,10,20,30)) +
  labs(x ="Year", y ="Water\ntemperature (C)", title ="Water temperature")
TemperatureFig

# River discharge
Afvoer <- Afvoer[which(Afvoer$mean <=7000 & (Afvoer$mean >=500)),] # remove excessive discharge values = errors in data set
Afvoer$Jaar<-as.factor(Afvoer$Jaar)
AfvoerYear <- Afvoer%>%
  group_by(Jaar)%>% 
  summarise(X2.5=quantile(mean, probs = 0.025),
            X97.5=quantile(mean, probs = 0.975),
            Mean=mean(mean), Max=max(mean), Min=min(mean), Median=median(mean), Std=sd(mean)) # Summarise per year
AfvoerYear2 <-AfvoerYear[c(11:39),] # select only 1990-2018 data

AfvoerFig<- ggplot(AfvoerYear2) +
  theme_bw() +
  theme(plot.title=element_textbox(hjust=0.5,size=20,margin=margin(t=5,b=5)), 
        axis.text=element_text(size=rel(1.5), colour = "black"), 
        axis.text.x=element_blank(),
        axis.title=element_text(size=rel(1.5), colour ="black"),
        axis.title.x=element_blank(),
        legend.position="none",
        axis.ticks = element_line(colour = "black", size = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        panel.grid.major = element_line(colour = "gray98"),
        panel.grid.minor = element_line(colour = "gray98"),
        plot.margin=unit(c(0.3,0.5,0.3,0.3),"cm")) +
  #geom_ribbon(data=AfvoerYear2, aes(Jaar, ymin = X2.5, ymax = X97.5, group=1), alpha=0.4, fill="snow3") +
  #geom_line(data=AfvoerYear2, aes(Jaar, Median, group=1), colour="snow4", size=0.8, alpha=0.6) +
  geom_pointrange(data=AfvoerYear2, aes(Jaar, Median, ymin = X2.5, ymax= X97.5), size = 1, alpha=1, colour="black") +
  geom_point(data=AfvoerYear2, aes(Jaar, Median, group=1), colour="black", size=4, alpha=1) +
  scale_x_discrete() +
  scale_y_continuous(limits=c(0, 8000), breaks=c(0,2000,4000,6000,8000),labels=c(0,2000,4000,6000, 8000)) +
  labs(x ="Year", y ="Discharge\n(m/s)", title ="River discharge")

AfvoerFig

# Oxygen levels
Oxygen <- Oxygen[-c(1)]
colnames(Oxygen)[1] <- "Jaar"
Oxygen$Jaar <- as.factor(Oxygen$Jaar)

Oxygen_fig<- ggplot(Oxygen) +
  theme_bw() +
  theme(plot.title=element_textbox(hjust=0.5,size=20,margin=margin(t=5,b=5)), 
        axis.text=element_text(size=rel(1.5), colour = "black"), 
        axis.text.x=element_blank(),
        axis.title=element_text(size=rel(1.5), colour ="black"),
        axis.title.x=element_blank(),
        legend.position="none",
        axis.ticks = element_line(colour = "black", size = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        panel.grid.major = element_line(colour = "gray98"),
        panel.grid.minor = element_line(colour = "gray98"),
        plot.margin=unit(c(0.3,0.5,0.3,0.3),"cm")) +
  #geom_ribbon(data=Oxygen, aes(Jaar, ymin = X2.5, ymax = X97.5, group=1), alpha=0.4, fill="snow3") +
  #geom_line(data=Oxygen, aes(Jaar, median, group=1), colour="snow4", size=0.8, alpha=0.6) +
  geom_pointrange(data=Oxygen, aes(Jaar, median, ymin = X2.5, ymax= X97.5), size = 1, alpha=1, colour="black") +
  geom_point(data=Oxygen, aes(Jaar, median, group=1), colour="black", size=4, alpha=1) +
  scale_x_discrete() +
  scale_y_continuous(limits=c(3, 15),breaks=c(5,10,15),labels=c(5,10,15)) +
  labs(x ="Year", y ="Oxygen\n(mg/l)", title ="Oxygen levels")

Oxygen_fig

# Fish abundances

Visdata_inheems<-fread("C:\\Users\\Stoff004\\OneDrive - WageningenUR\\2020 30 jaar geulen paper\\Analyse\\Analyse R\\Inheems_vis_file_20200122.csv")
Visdata_uitheems<-fread("C:\\Users\\Stoff004\\OneDrive - WageningenUR\\2020 30 jaar geulen paper\\Analyse\\Analyse R\\Uitheems_vis_file_20200122.csv")
Total_database<-rbind(Visdata_inheems, Visdata_uitheems) #combineren van de twee datasets (zelfde kolommen, onder elkaar dus Rbind)
Achtergrond<-fread("C:\\Users\\Stoff004\\Dropbox\\2020 30 jaar nevengeulen paper\\Analyse\\Analyse R\\Subset_Trawllist_relevant_20200122.csv")
Rheo_limno<-read.csv(file="species2.csv")
species<-fread("C:\\Users\\Stoff004\\Dropbox\\2020 30 jaar nevengeulen paper\\Analyse\\Analyse R\\species.csv")

# alleen boomkor bemonsteringen zijn meegenomen!

# inheems
Achtergrond$Combo<-with(Achtergrond, paste0(sample,"_", year)) # kolom maken met unique waarde voor locaties
Total_database$Combo<-with(Total_database, paste0(sample,"_", year)) # kolom maken met unique waarde voor locaties

Subset_visdata<-Total_database[Total_database$Combo %in% Achtergrond$Combo] # subset van de visdata aan de hand van de unieke locatie waardes die voorkomen in het geprepareerde achtergrond bestand
names(Subset_visdata)[18] <- "Volledige.naam" # nieuwe naam soort kolom MWTL
names(species)[4] <- "SCIENTIFIC_NAME" 
names(Rheo_limno)[1] <- "Soortnaam"
Subset_visdata <- Subset_visdata[which(Subset_visdata$SCIENTIFIC_NAME !="Osmerus eperlanus"),] # remove samples with Osmerus eperlanus, since this is a schooling rheophilic fish

Subset_visdata_2 <- merge(Subset_visdata, species [,1:2], by="Volledige.naam") #remove mistakes in fish names by correcting with list of all possible fishname mistakes
Subset_visdata_type<-merge(Subset_visdata_2, Rheo_limno, by="Soortnaam") #toevoegen van Rheo/Limno gegevens

Samples<-as.data.frame(count(Achtergrond, vars = "year"))
Samples <- Samples[-1, ] # removes 1992

Rheofiel <- Subset_visdata_type[ which(Subset_visdata_type$Guild2=='Rheo'),]
Eurytoop <- Subset_visdata_type[ which(Subset_visdata_type$Guild2=='Eury'),]
Limnofiel <- Subset_visdata_type[ which(Subset_visdata_type$Guild2=='Limno'),]

science_theme = theme(panel.grid.major = element_line(size = 0.4),axis.title.y = element_text(vjust=1.3),axis.title.x = element_text(vjust=-1.5),axis.line = element_line(size = 0.7, color = "black"), legend.title=element_blank(),legend.position = "bottom",text = element_text(size = 17), axis.text.x=element_text(angle = 45))

# Rheofiel
# vaststellen welke locaties uit Achtergrond niet aanwezig zijn in subset rheofiele vis
Common_locations<-intersect(Rheofiel$Combo, Achtergrond$Combo)
Verschil_locaties<-Achtergrond[!Achtergrond$Combo %in% Common_locations,]
Verschil_locaties$cpue<-0.00

# alle ontbrekende locaties een sum van 0 toewijzen - namenlijk geen vis gevangen!
# nieuwe datasets bouwen
Combi_vis<-subset(Rheofiel, select=c("Combo", "cpue"))
Combi_0<-subset(Verschil_locaties, select=c("Combo", "cpue"))
Combi_totaal<-rbind(Combi_vis,Combi_0)

SummaryBestand_Rheofiel<-ddply(Combi_totaal,.(Combo), summarize, sum=((sum(cpue))/100)) # Geeft 1 gesommeerde cpue per unieke locatie
SummaryBestand_Rheofiel$sum_0.01<-SummaryBestand_Rheofiel$sum+0.01 # voegt aan elke gesommeere cpue per unieke locatie 0.01 toe --> log trans 0 waarde!

Total_Rheofiel_jaar<-merge(SummaryBestand_Rheofiel, Achtergrond, by="Combo") # voegt aan elke gesommeerde cpue per locatie alle achtergrond info toe
Total_Rheofiel_jaar$year<-as.factor(Total_Rheofiel_jaar$year)

Sum_Total_rheofiel_jaar<-ddply(Total_Rheofiel_jaar,.(year), summarize, sum_aantal=(sum(sum_0.01)), X2.5=quantile(sum_0.01, probs = 0.025), 
                               X97.5=quantile(sum_0.01, probs = 0.975), mean=mean(sum_0.01), median=median(sum_0.01)) # Geeft 1 gesommeerde cpue per unieke locatie

write.csv(Sum_Total_rheofiel_jaar,"C:\\Users\\Stoff004\\OneDrive - WageningenUR\\2020 30 jaar geulen paper\\Analyse\\Analyse R\\Sum_Total_rheofiel_jaar.csv")

# Limnofiel
# vaststellen welke locaties uit Achtergrond niet aanwezig zijn in subset rheofiele vis
Common_locations<-intersect(Limnofiel$Combo, Achtergrond$Combo)
Verschil_locaties<-Achtergrond[!Achtergrond$Combo %in% Common_locations,]
Verschil_locaties$cpue<-0.00

# alle ontbrekende locaties een sum van 0 toewijzen - namenlijk geen vis gevangen!
# nieuwe datasets bouwen
Combi_vis<-subset(Limnofiel, select=c("Combo", "cpue"))
Combi_0<-subset(Verschil_locaties, select=c("Combo", "cpue"))
Combi_totaal<-rbind(Combi_vis,Combi_0)

SummaryBestand_Limnofiel<-ddply(Combi_totaal,.(Combo), summarize, sum=((sum(cpue))/100)) # Geeft 1 gesommeerde cpue per unieke locatie
SummaryBestand_Limnofiel$sum_0.01<-SummaryBestand_Limnofiel$sum+0.01 # voegt aan elke gesommeere cpue per unieke locatie 0.01 toe --> log trans 0 waarde!

Total_Limnofiel_jaar<-merge(SummaryBestand_Limnofiel, Achtergrond, by="Combo") # voegt aan elke gesommeerde cpue per locatie alle achtergrond info toe
Total_Limnofiel_jaar$year<-as.factor(Total_Limnofiel_jaar$year)

Sum_Total_limnofiel_jaar<-ddply(Total_Limnofiel_jaar,.(year), summarize, sum_aantal=(sum(sum_0.01)), X2.5=quantile(sum_0.01, probs = 0.025), 
                               X97.5=quantile(sum_0.01, probs = 0.975), mean=mean(sum_0.01), median=median(sum_0.01)) # Geeft 1 gesommeerde cpue per unieke locatie

write.csv(Sum_Total_limnofiel_jaar,"C:\\Users\\Stoff004\\OneDrive - WageningenUR\\2020 30 jaar geulen paper\\Analyse\\Analyse R\\Sum_Total_limnofiel_jaar.csv")

# Eurytoop
# vaststellen welke locaties uit Achtergrond niet aanwezig zijn in subset rheofiele vis
Common_locations<-intersect(Eurytoop$Combo, Achtergrond$Combo)
Verschil_locaties<-Achtergrond[!Achtergrond$Combo %in% Common_locations,]
Verschil_locaties$cpue<-0.00

# alle ontbrekende locaties een sum van 0 toewijzen - namenlijk geen vis gevangen!
# nieuwe datasets bouwen
Combi_vis<-subset(Eurytoop, select=c("Combo", "cpue"))
Combi_0<-subset(Verschil_locaties, select=c("Combo", "cpue"))
Combi_totaal<-rbind(Combi_vis,Combi_0)

SummaryBestand_Eurytoop<-ddply(Combi_totaal,.(Combo), summarize, sum=((sum(cpue))/100)) # Geeft 1 gesommeerde cpue per unieke locatie
SummaryBestand_Eurytoop$sum_0.01<-SummaryBestand_Eurytoop$sum+0.01 # voegt aan elke gesommeere cpue per unieke locatie 0.01 toe --> log trans 0 waarde!

Total_Eurytoop_jaar<-merge(SummaryBestand_Eurytoop, Achtergrond, by="Combo") # voegt aan elke gesommeerde cpue per locatie alle achtergrond info toe
Total_Eurytoop_jaar$year<-as.factor(Total_Eurytoop_jaar$year)

Sum_Total_eurytoop_jaar<-ddply(Total_Eurytoop_jaar,.(year), summarize, sum_aantal=(sum(sum_0.01)), X2.5=quantile(sum_0.01, probs = 0.025), 
                               X97.5=quantile(sum_0.01, probs = 0.975), mean=mean(sum_0.01), median=median(sum_0.01)) # Geeft 1 gesommeerde cpue per unieke locatie

write.csv(Sum_Total_eurytoop_jaar,"C:\\Users\\Stoff004\\OneDrive - WageningenUR\\2020 30 jaar geulen paper\\Analyse\\Analyse R\\Sum_Total_eurytoop_jaar.csv")


### Ook meteen soortenrijkdom uitrekenen
Subset_visdata_2 <- merge(Subset_visdata, species [,1:2], by="Volledige.naam") #remove mistakes in fish names by correcting with list of all possible fishname mistakes
Subset_visdata_type<-merge(Subset_visdata_2, Rheo_limno, by="Soortnaam") #toevoegen van Rheo/Limno gegevens

write.csv(Subset_visdata_type, "C:\\Users\\Stoff004\\OneDrive - WageningenUR\\2020 30 jaar geulen paper\\Analyse\\Analyse R\\Soortenrijkdom_ruw.csv")


# Abundances
MWTL_rheophilics <- read.csv(file="Sum_Total_rheofiel_jaar.csv", sep=",")
MWTL_rheophilics$guild <- "Rheo"
MWTL_limnophilics <- read.csv(file="Sum_Total_limnofiel_jaar.csv", sep=",")
MWTL_limnophilics$guild <- "Limno" 
MWTL_eurytopics <- read.csv(file="Sum_Total_eurytoop_jaar.csv", sep=",")
MWTL_eurytopics$guild <- "Eury"
#MWTL_abun <- rbind(MWTL_rheophilics, MWTL_limnophilics, MWTL_eurytopics)

# Combine species in 1 plot
MWTL_test <- merge(MWTL_rheophilics, MWTL_eurytopics[c(2,6)], by="year")
names(MWTL_test)[6] <- "Rheo"
names(MWTL_test)[9] <- "Eury"
MWTL_test <- merge(MWTL_test, MWTL_limnophilics[c(2,6)], by="year")
names(MWTL_test)[10] <- "Limno"
MWTL_test2 <- MWTL_test[c(1,9,6,10)]
MWTL_test2 <- MWTL_test2[-1,]
summary(MWTL_test2)
# Create empty data frame for 1990,1991,1992
a <- 1990:1992
b <- NA 
c <- NA
d <- NA
dat <- data.frame (a, b, c, d)
names(dat) <- c("year", "Eury", "Rheo", "Limno")
MWTL_fish <- rbind(dat, MWTL_test2) # add empty data frame to fish abun data frame

MWTL_fish$year <- as.factor(MWTL_fish$year)

#  Add Species richness
MWTL_richness <- read.csv(file="Soortenrijkdom_20200220.csv", sep=";")
MWTL_richness <- MWTL_richness[-c(5)]
MWTL_richness$year <- as.factor(MWTL_richness$year)

MWTL_masterfish <- merge(MWTL_fish, MWTL_richness, by="year")
names(MWTL_masterfish) <- c("year","Eury","Rheo","Limno","Rheo_spec","Eury_spec","Limno_spec")


# Plot abundances
Abuntotal_fig<- ggplot(MWTL_masterfish) +
  theme_bw() +
  theme(plot.title=element_textbox(hjust=0.5,size=20,margin=margin(t=5,b=5)), 
        axis.text=element_text(size=rel(1.5), colour = "black"), 
        axis.text.x=element_blank(),
        axis.title=element_text(size=rel(1.5), colour ="black"),
        axis.title.x=element_blank(),
        legend.position="none",
        axis.ticks = element_line(colour = "black", size = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        panel.grid.major = element_line(colour = "gray98"),
        panel.grid.minor = element_line(colour = "gray98"),
        plot.margin=unit(c(0.3,0.5,0.3,0.3),"cm")) +
  geom_line(data = MWTL_masterfish, aes(x = year, y = Rheo, group=1), color = "darkblue", size = 1, alpha=0.6) +
  geom_point(data = MWTL_masterfish, aes(x = year, y = Rheo, group=1), color = "darkblue", size = 4, alpha=1) +
  geom_line(data = MWTL_masterfish, aes(x = year, y = Eury, group=1), color = "darkred", size = 1, alpha=0.6) +
  geom_point(data = MWTL_masterfish, aes(x = year, y = Eury, group=1), color = "darkred", size = 4, alpha=1) +
  geom_line(data = MWTL_masterfish, aes(x = year, y = Limno, group=1), color = "darkgreen", size = 1, alpha=0.6) +
  geom_point(data = MWTL_masterfish, aes(x = year, y = Limno, group=1), color = "darkgreen", size = 4, alpha=1) +
  scale_x_discrete(breaks = c(1990,1991,1992,1993,1994,1995,1996,1997,1998,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008,2009
                              ,2010,2011,2012,2013,2014,2015,2016,2017,2018)) +
  scale_y_continuous(trans = log_trans(), limits=c(0.01,10), breaks = c(0.01, 0.1, 1, 10)) +
  labs(x ="Year", y ="Abundance\n(#/100 m)", title ="Fish abundances")
Abuntotal_fig


#Plot species richness
SRtotal_fig<- ggplot(MWTL_masterfish) +
  theme_bw() +
  theme(plot.title=element_textbox(hjust=0.5,size=20,margin=margin(t=5,b=5)), 
        axis.text=element_text(size=rel(1.5), colour = "black"), 
        axis.text.x=element_blank(),
        axis.title=element_text(size=rel(1.5), colour ="black"),
        axis.title.x=element_blank(),
        legend.position="none",
        axis.ticks = element_line(colour = "black", size = 1),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        panel.grid.major = element_line(colour = "gray98"),
        panel.grid.minor = element_line(colour = "gray98"),
        plot.margin=unit(c(0.3,0.5,0.3,0.3),"cm")) +
  geom_line(data = MWTL_masterfish, aes(x = year, y = Rheo_spec, group=1), color = "darkblue", size = 1, alpha=0.6) +
  geom_point(data = MWTL_masterfish, aes(x = year, y = Rheo_spec, group=1), shape=15, color = "darkblue", size = 3, alpha=1) +
  geom_line(data = MWTL_masterfish, aes(x = year, y = Eury_spec, group=1), color = "darkred", size = 1, alpha=0.6) +
  geom_point(data = MWTL_masterfish, aes(x = year, y = Eury_spec, group=1), shape=15, color = "darkred", size = 3, alpha=1) +
  geom_line(data = MWTL_masterfish, aes(x = year, y = Limno_spec, group=1), color = "darkgreen", size = 1, alpha=0.6) +
  geom_point(data = MWTL_masterfish, aes(x = year, y = Limno_spec, group=1), shape=15, color = "darkgreen", size = 3, alpha=1) +
  scale_x_discrete() +
  scale_y_continuous(limits=c(0,15)) +
  labs(x ="Year", y ="Number of species", title ="Species richness")
SRtotal_fig


plot_grid(Abuntotal_fig, SRtotal_fig, AfvoerFig, TemperatureFig, PhosphateFig, Oxygen_fig,
          align = "v", nrow = 3)

# Test for long-term effects in river fish community composition - Linear regression
rheo <-  MWTL_masterfish$Rheo[c(4:28)]
eury <-  MWTL_masterfish$Eury[c(4:28)]
limno <- MWTL_masterfish$Limno[c(4:28)]
spec_rheo <-  MWTL_masterfish$Rheo_spec[c(4:28)]
spec_eury <-  MWTL_masterfish$Eury_spec[c(4:28)]
spec_limno <- MWTL_masterfish$Limno_spec[c(4:28)]
year <- MWTL_masterfish$year[c(4:28)]
year <- as.numeric(year)

trend_rheo <-  lm(rheo ~ year)
trend_eury <-  lm(eury ~ year)
trend_limno <- lm(limno ~ year)
trend_rheo_spec  <- lm(spec_rheo ~ year)
trend_eury_spec  <- lm(spec_eury ~ year)
trend_limno_spec <- lm(spec_limno ~ year)

summary(trend_rheo) # R-squared:  0.04668, p-value: 0.2996
summary(trend_eury) # R-squared:  0.4608, p-value: 0.0001911 = SIGNIFICANT!
summary(trend_limno) # R-squared:  0.02254, p-value: 0.4738
summary(trend_rheo_spec) # R-squared:  0.02279, p-value: 0.4713
summary(trend_eury_spec) # R-squared:  0.009231, p-value: 0.6478
summary(trend_limno_spec) # R-squared:  0.01526, p-value: 0.5563

# Test for long-term effects in water quality and discharge levels - Linear regression
temp <- Temperature$median[c(1:28)]
year_temp <- Temperature$Jaar[c(1:28)]
year_temp <- as.numeric(year_temp)
trend_temp <- lm(temp ~ year_temp)
summary(trend_temp) # NS

oxy <- Oxygen$median[c(1:28)]
year_temp <- Temperature$Jaar[c(1:28)]
year_temp <- as.numeric(year_temp)
trend_oxy <- lm(oxy ~ year_temp)
summary(trend_oxy) # R-squared:  0.4473, p-value: 0.0001001, F-statistic: 21.04 on 1 and 26 DF

phos <- Phosphate$median[c(1:28)]
year_temp <- Temperature$Jaar[c(1:28)]
year_temp <- as.numeric(year_temp)
trend_phos <- lm(phos ~ year_temp)
summary(trend_phos) # R-squared:  0.7206, p-value: 1.14e-08, F-statistic: 67.05 on 1 and 26 DF

discharge <- AfvoerYear2$Median
year_dis <- AfvoerYear2$Jaar
year_dis <- as.numeric(year_dis)
trend_dis <- lm(discharge ~ year_dis)
summary(trend_dis) # NS

